/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/EnumTraits.h>

namespace IPC {

enum class ReceiverName : uint8_t {
    AuthenticationManager = 1
    , AuxiliaryProcess = 2
    , CacheStorageEngineConnection = 3
    , DownloadProxy = 4
    , DrawingArea = 5
    , DrawingAreaProxy = 6
    , EventDispatcher = 7
    , GPUConnectionToWebProcess = 8
    , GPUProcess = 9
    , GPUProcessConnection = 10
    , GPUProcessProxy = 11
    , GtkSettingsManagerProxy = 12
    , LibWebRTCCodecs = 13
    , LibWebRTCCodecsProxy = 14
    , LibWebRTCNetwork = 15
    , MediaPlayerPrivateRemote = 16
    , MediaSourcePrivateRemote = 17
    , NetworkBroadcastChannelRegistry = 18
    , NetworkConnectionToWebProcess = 19
    , NetworkContentRuleListManager = 20
    , NetworkMDNSRegister = 21
    , NetworkProcess = 22
    , NetworkProcessConnection = 23
    , NetworkProcessProxy = 24
    , NetworkRTCMonitor = 25
    , NetworkRTCProvider = 26
    , NetworkResourceLoader = 27
    , NetworkSocketChannel = 28
    , NetworkSocketStream = 29
    , NetworkStorageManager = 30
    , NotificationManagerMessageHandler = 31
    , PlatformXRSystem = 32
    , PlatformXRSystemProxy = 33
    , RTCDataChannelRemoteManager = 34
    , RTCDataChannelRemoteManagerProxy = 35
    , RemoteAdapter = 36
    , RemoteAudioDestinationManager = 37
    , RemoteAudioHardwareListener = 38
    , RemoteAudioMediaStreamTrackRendererInternalUnitManager = 39
    , RemoteAudioSession = 40
    , RemoteAudioSessionProxy = 41
    , RemoteAudioSourceProviderManager = 42
    , RemoteBindGroup = 43
    , RemoteBindGroupLayout = 44
    , RemoteBuffer = 45
    , RemoteCDMFactoryProxy = 46
    , RemoteCDMInstance = 47
    , RemoteCDMInstanceProxy = 48
    , RemoteCDMInstanceSession = 49
    , RemoteCDMInstanceSessionProxy = 50
    , RemoteCDMProxy = 51
    , RemoteCommandBuffer = 52
    , RemoteCommandEncoder = 53
    , RemoteComputePassEncoder = 54
    , RemoteComputePipeline = 55
    , RemoteDevice = 56
    , RemoteDisplayListRecorder = 57
    , RemoteExternalTexture = 58
    , RemoteGPU = 59
    , RemoteGraphicsContextGL = 60
    , RemoteGraphicsContextGLProxy = 61
    , RemoteLegacyCDMFactoryProxy = 62
    , RemoteLegacyCDMProxy = 63
    , RemoteLegacyCDMSession = 64
    , RemoteLegacyCDMSessionProxy = 65
    , RemoteMediaEngineConfigurationFactoryProxy = 66
    , RemoteMediaPlayerManagerProxy = 67
    , RemoteMediaPlayerProxy = 68
    , RemoteMediaRecorder = 69
    , RemoteMediaRecorderManager = 70
    , RemoteMediaResourceManager = 71
    , RemoteMediaSessionCoordinator = 72
    , RemoteMediaSessionCoordinatorProxy = 73
    , RemoteMediaSourceProxy = 74
    , RemotePipelineLayout = 75
    , RemoteQuerySet = 76
    , RemoteQueue = 77
    , RemoteRemoteCommandListener = 78
    , RemoteRemoteCommandListenerProxy = 79
    , RemoteRenderBundle = 80
    , RemoteRenderBundleEncoder = 81
    , RemoteRenderPassEncoder = 82
    , RemoteRenderPipeline = 83
    , RemoteRenderingBackend = 84
    , RemoteRenderingBackendProxy = 85
    , RemoteSampleBufferDisplayLayer = 86
    , RemoteSampleBufferDisplayLayerManager = 87
    , RemoteSampler = 88
    , RemoteShaderModule = 89
    , RemoteSourceBufferProxy = 90
    , RemoteTexture = 91
    , RemoteTextureView = 92
    , RemoteWebInspectorUI = 93
    , RemoteWebInspectorUIProxy = 94
    , SampleBufferDisplayLayer = 95
    , ServiceWorkerFetchTask = 96
    , SourceBufferPrivateRemote = 97
    , SpeechRecognitionRealtimeMediaSourceManager = 98
    , SpeechRecognitionRemoteRealtimeMediaSourceManager = 99
    , SpeechRecognitionServer = 100
    , StorageAreaMap = 101
    , StorageManagerSet = 102
    , ViewGestureController = 103
    , ViewGestureGeometryCollector = 104
    , VisitedLinkStore = 105
    , VisitedLinkTableController = 106
    , WebAutomationSession = 107
    , WebAutomationSessionProxy = 108
    , WebBroadcastChannelRegistry = 109
    , WebConnection = 110
    , WebCookieManager = 111
    , WebCookieManagerProxy = 112
    , WebFullScreenManager = 113
    , WebFullScreenManagerProxy = 114
    , WebGeolocationManager = 115
    , WebGeolocationManagerProxy = 116
    , WebIDBConnectionToServer = 117
    , WebIDBServer = 118
    , WebInspector = 119
    , WebInspectorInterruptDispatcher = 120
    , WebInspectorUI = 121
    , WebInspectorUIProxy = 122
    , WebMDNSRegister = 123
    , WebNotificationManager = 124
    , WebPage = 125
    , WebPageProxy = 126
    , WebPasteboardProxy = 127
    , WebProcess = 128
    , WebProcessPool = 129
    , WebProcessProxy = 130
    , WebRTCMonitor = 131
    , WebRTCResolver = 132
    , WebResourceLoader = 133
    , WebSWClientConnection = 134
    , WebSWContextManagerConnection = 135
    , WebSWServerConnection = 136
    , WebSWServerToContextConnection = 137
    , WebSocketChannel = 138
    , WebSocketStream = 139
    , WebSpeechRecognitionConnection = 140
    , WebUserContentController = 141
    , WebUserContentControllerProxy = 142
    , IPC = 143
    , AsyncReply = 144
    , Invalid = 145
};

enum class MessageName : uint16_t {
    AuthenticationManager_CompleteAuthenticationChallenge
    , AuxiliaryProcess_DidReceiveMemoryPressureEvent
    , AuxiliaryProcess_MainThreadPing
    , AuxiliaryProcess_SetProcessSuppressionEnabled
    , AuxiliaryProcess_ShutDown
    , CacheStorageEngineConnection_Caches
    , CacheStorageEngineConnection_ClearMemoryRepresentation
    , CacheStorageEngineConnection_DeleteMatchingRecords
    , CacheStorageEngineConnection_Dereference
    , CacheStorageEngineConnection_EngineRepresentation
    , CacheStorageEngineConnection_Open
    , CacheStorageEngineConnection_PutRecords
    , CacheStorageEngineConnection_Reference
    , CacheStorageEngineConnection_Remove
    , CacheStorageEngineConnection_RetrieveRecords
    , DownloadProxy_DecideDestinationWithSuggestedFilename
    , DownloadProxy_DidCreateDestination
    , DownloadProxy_DidFail
    , DownloadProxy_DidFinish
    , DownloadProxy_DidReceiveAuthenticationChallenge
    , DownloadProxy_DidReceiveData
    , DownloadProxy_DidStart
    , DownloadProxy_WillSendRequest
    , DrawingAreaProxy_DidFirstLayerFlush
    , DrawingAreaProxy_DidUpdateBackingStoreState
    , DrawingAreaProxy_DidUpdateGeometry
    , DrawingAreaProxy_DispatchPresentationCallbacksAfterFlushingLayers
    , DrawingAreaProxy_EnterAcceleratedCompositingMode
    , DrawingAreaProxy_ExitAcceleratedCompositingMode
    , DrawingAreaProxy_Update
    , DrawingAreaProxy_UpdateAcceleratedCompositingMode
    , DrawingArea_AcceleratedAnimationDidEnd
    , DrawingArea_AcceleratedAnimationDidStart
    , DrawingArea_AddTransactionCallbackID
    , DrawingArea_AdjustTransientZoom
    , DrawingArea_CommitTransientZoom
    , DrawingArea_DidUpdate
    , DrawingArea_SetColorSpace
    , DrawingArea_SetDeviceScaleFactor
    , DrawingArea_SetViewExposedRect
    , DrawingArea_UpdateBackingStoreState
    , DrawingArea_UpdateGeometry
    , EventDispatcher_DisplayWasRefreshed
    , EventDispatcher_GestureEvent
    , EventDispatcher_TouchEvent
    , EventDispatcher_TouchEventWithoutCallback
    , EventDispatcher_WheelEvent
    , GPUConnectionToWebProcess_ClearNowPlayingInfo
    , GPUConnectionToWebProcess_ConfigureLoggingChannel
    , GPUConnectionToWebProcess_CreateAudioHardwareListener
    , GPUConnectionToWebProcess_CreateGraphicsContextGL
    , GPUConnectionToWebProcess_CreateRemoteCommandListener
    , GPUConnectionToWebProcess_CreateRenderingBackend
    , GPUConnectionToWebProcess_CreateVisibilityPropagationContextForPage
    , GPUConnectionToWebProcess_CreateWCLayerTreeHost
    , GPUConnectionToWebProcess_DestroyVisibilityPropagationContextForPage
    , GPUConnectionToWebProcess_EnableVP9Decoders
    , GPUConnectionToWebProcess_EnsureMediaSessionHelper
    , GPUConnectionToWebProcess_ReleaseAudioHardwareListener
    , GPUConnectionToWebProcess_ReleaseGraphicsContextGL
    , GPUConnectionToWebProcess_ReleaseRemoteCommandListener
    , GPUConnectionToWebProcess_ReleaseRenderingBackend
    , GPUConnectionToWebProcess_ReleaseWCLayerTreeHost
    , GPUConnectionToWebProcess_SetMediaOverridesForTesting
    , GPUConnectionToWebProcess_SetNowPlayingInfo
    , GPUConnectionToWebProcess_SetUserPreferredLanguages
    , GPUProcessConnection_BeginRoutingArbitrationWithCategory
    , GPUProcessConnection_DidReceiveRemoteCommand
    , GPUProcessConnection_EndRoutingArbitration
    , GPUProcessConnection_ResetAudioMediaStreamTrackRendererInternalUnit
    , GPUProcessProxy_DidCreateContextForVisibilityPropagation
    , GPUProcessProxy_ProcessIsReadyToExit
    , GPUProcessProxy_TerminateWebProcess
    , GPUProcess_AddMockMediaDevice
    , GPUProcess_AddSession
    , GPUProcess_ClearMockMediaDevices
    , GPUProcess_ConsumeAudioComponentRegistrations
    , GPUProcess_CreateGPUConnectionToWebProcess
    , GPUProcess_DisplayConfigurationChanged
    , GPUProcess_InitializeGPUProcess
    , GPUProcess_NotifyPreferencesChanged
    , GPUProcess_PrepareToSuspend
    , GPUProcess_ProcessDidResume
    , GPUProcess_RemoveMockMediaDevice
    , GPUProcess_RemoveSession
    , GPUProcess_ResetMockMediaDevices
    , GPUProcess_SetMediaSourceInlinePaintingEnabled
    , GPUProcess_SetMockCameraIsInterrupted
    , GPUProcess_SetMockCaptureDevicesEnabled
    , GPUProcess_SetOpusDecoderEnabled
    , GPUProcess_SetOrientationForMediaCapture
    , GPUProcess_SetScreenProperties
    , GPUProcess_SetVorbisDecoderEnabled
    , GPUProcess_SetWebMFormatReaderEnabled
    , GPUProcess_SetWebMParserEnabled
    , GPUProcess_UpdateCaptureAccess
    , GPUProcess_UpdateCaptureOrigin
    , GPUProcess_UpdateSandboxAccess
    , GPUProcess_WebProcessConnectionCountForTesting
    , GtkSettingsManagerProxy_SettingsDidChange
    , LibWebRTCCodecsProxy_CreateEncoder
    , LibWebRTCCodecsProxy_CreateH264Decoder
    , LibWebRTCCodecsProxy_CreateH265Decoder
    , LibWebRTCCodecsProxy_CreateVP9Decoder
    , LibWebRTCCodecsProxy_DecodeFrame
    , LibWebRTCCodecsProxy_EncodeFrame
    , LibWebRTCCodecsProxy_InitializeEncoder
    , LibWebRTCCodecsProxy_ReleaseDecoder
    , LibWebRTCCodecsProxy_ReleaseEncoder
    , LibWebRTCCodecsProxy_SetEncodeRates
    , LibWebRTCCodecsProxy_SetFrameSize
    , LibWebRTCCodecsProxy_SetRTCLoggingLevel
    , LibWebRTCCodecs_CompletedDecoding
    , LibWebRTCCodecs_CompletedEncoding
    , LibWebRTCCodecs_FailedDecoding
    , LibWebRTCNetwork_SignalAddressReady
    , LibWebRTCNetwork_SignalClose
    , LibWebRTCNetwork_SignalConnect
    , LibWebRTCNetwork_SignalNewConnection
    , LibWebRTCNetwork_SignalReadPacket
    , LibWebRTCNetwork_SignalSentPacket
    , MediaPlayerPrivateRemote_ActiveSourceBuffersChanged
    , MediaPlayerPrivateRemote_AddDataCue
    , MediaPlayerPrivateRemote_AddDataCueWithType
    , MediaPlayerPrivateRemote_AddGenericCue
    , MediaPlayerPrivateRemote_AddRemoteAudioTrack
    , MediaPlayerPrivateRemote_AddRemoteTextTrack
    , MediaPlayerPrivateRemote_AddRemoteVideoTrack
    , MediaPlayerPrivateRemote_CharacteristicChanged
    , MediaPlayerPrivateRemote_CurrentPlaybackTargetIsWirelessChanged
    , MediaPlayerPrivateRemote_CurrentTimeChanged
    , MediaPlayerPrivateRemote_DurationChanged
    , MediaPlayerPrivateRemote_EngineFailedToLoad
    , MediaPlayerPrivateRemote_FirstVideoFrameAvailable
    , MediaPlayerPrivateRemote_GetRawCookies
    , MediaPlayerPrivateRemote_InitializationDataEncountered
    , MediaPlayerPrivateRemote_MediaPlayerKeyNeeded
    , MediaPlayerPrivateRemote_MuteChanged
    , MediaPlayerPrivateRemote_NetworkStateChanged
    , MediaPlayerPrivateRemote_ParseWebVTTCueData
    , MediaPlayerPrivateRemote_ParseWebVTTCueDataStruct
    , MediaPlayerPrivateRemote_ParseWebVTTFileHeader
    , MediaPlayerPrivateRemote_PlaybackStateChanged
    , MediaPlayerPrivateRemote_PushVideoFrameMetadata
    , MediaPlayerPrivateRemote_RateChanged
    , MediaPlayerPrivateRemote_ReadyStateChanged
    , MediaPlayerPrivateRemote_RemoteAudioTrackConfigurationChanged
    , MediaPlayerPrivateRemote_RemoteTextTrackConfigurationChanged
    , MediaPlayerPrivateRemote_RemoteVideoTrackConfigurationChanged
    , MediaPlayerPrivateRemote_RemoveDataCue
    , MediaPlayerPrivateRemote_RemoveGenericCue
    , MediaPlayerPrivateRemote_RemoveRemoteAudioTrack
    , MediaPlayerPrivateRemote_RemoveRemoteTextTrack
    , MediaPlayerPrivateRemote_RemoveRemoteVideoTrack
    , MediaPlayerPrivateRemote_RemoveResource
    , MediaPlayerPrivateRemote_RenderingModeChanged
    , MediaPlayerPrivateRemote_RequestResource
    , MediaPlayerPrivateRemote_ResourceNotSupported
    , MediaPlayerPrivateRemote_SendH2Ping
    , MediaPlayerPrivateRemote_SizeChanged
    , MediaPlayerPrivateRemote_TimeChanged
    , MediaPlayerPrivateRemote_UpdateCachedState
    , MediaPlayerPrivateRemote_UpdateDataCue
    , MediaPlayerPrivateRemote_UpdateGenericCue
    , MediaPlayerPrivateRemote_VolumeChanged
    , MediaPlayerPrivateRemote_WaitingForKeyChanged
    , MediaSourcePrivateRemote_SeekToTime
    , NetworkBroadcastChannelRegistry_PostMessage
    , NetworkBroadcastChannelRegistry_RegisterChannel
    , NetworkBroadcastChannelRegistry_UnregisterChannel
    , NetworkConnectionToWebProcess_AddOriginAccessAllowListEntry
    , NetworkConnectionToWebProcess_BrowsingContextRemoved
    , NetworkConnectionToWebProcess_CheckRemotePortForActivity
    , NetworkConnectionToWebProcess_ClearPageSpecificData
    , NetworkConnectionToWebProcess_CloseSWContextConnection
    , NetworkConnectionToWebProcess_ConnectToRTCDataChannelRemoteSource
    , NetworkConnectionToWebProcess_ConvertMainResourceLoadToDownload
    , NetworkConnectionToWebProcess_CreateNewMessagePortChannel
    , NetworkConnectionToWebProcess_CreateRTCProvider
    , NetworkConnectionToWebProcess_CreateSocketChannel
    , NetworkConnectionToWebProcess_CreateSocketStream
    , NetworkConnectionToWebProcess_DeleteCookie
    , NetworkConnectionToWebProcess_DidDeliverMessagePortMessages
    , NetworkConnectionToWebProcess_EntangleLocalPortInThisProcessToRemote
    , NetworkConnectionToWebProcess_EstablishSWContextConnection
    , NetworkConnectionToWebProcess_HasStorageAccess
    , NetworkConnectionToWebProcess_IsResourceLoadFinished
    , NetworkConnectionToWebProcess_LoadPing
    , NetworkConnectionToWebProcess_LogUserInteraction
    , NetworkConnectionToWebProcess_MessagePortClosed
    , NetworkConnectionToWebProcess_MessagePortDisentangled
    , NetworkConnectionToWebProcess_PageLoadCompleted
    , NetworkConnectionToWebProcess_PostMessageToRemote
    , NetworkConnectionToWebProcess_PreconnectTo
    , NetworkConnectionToWebProcess_PrefetchDNS
    , NetworkConnectionToWebProcess_PrioritizeResourceLoads
    , NetworkConnectionToWebProcess_RegisterBlobURL
    , NetworkConnectionToWebProcess_RegisterBlobURLForSlice
    , NetworkConnectionToWebProcess_RegisterBlobURLFromURL
    , NetworkConnectionToWebProcess_RegisterBlobURLHandle
    , NetworkConnectionToWebProcess_RegisterBlobURLOptionallyFileBacked
    , NetworkConnectionToWebProcess_RegisterFileBlobURL
    , NetworkConnectionToWebProcess_RegisterURLSchemesAsCORSEnabled
    , NetworkConnectionToWebProcess_RemoveLoadIdentifier
    , NetworkConnectionToWebProcess_RemoveOriginAccessAllowListEntry
    , NetworkConnectionToWebProcess_RemoveStorageAccessForFrame
    , NetworkConnectionToWebProcess_RequestStorageAccess
    , NetworkConnectionToWebProcess_RequestStorageAccessUnderOpener
    , NetworkConnectionToWebProcess_ResetOriginAccessAllowLists
    , NetworkConnectionToWebProcess_ResourceLoadStatisticsUpdated
    , NetworkConnectionToWebProcess_ScheduleResourceLoad
    , NetworkConnectionToWebProcess_SendH2Ping
    , NetworkConnectionToWebProcess_SetCORSDisablingPatterns
    , NetworkConnectionToWebProcess_SetCaptureExtraNetworkLoadMetricsEnabled
    , NetworkConnectionToWebProcess_SetCookiesFromDOM
    , NetworkConnectionToWebProcess_SetRawCookie
    , NetworkConnectionToWebProcess_SetResourceLoadSchedulingMode
    , NetworkConnectionToWebProcess_StartDownload
    , NetworkConnectionToWebProcess_TakeAllMessagesForPort
    , NetworkConnectionToWebProcess_UnregisterBlobURL
    , NetworkConnectionToWebProcess_UnregisterBlobURLHandle
    , NetworkConnectionToWebProcess_UnsubscribeFromCookieChangeNotifications
    , NetworkConnectionToWebProcess_UpdateActivePages
    , NetworkConnectionToWebProcess_UpdateQuotaBasedOnSpaceUsageForTesting
    , NetworkConnectionToWebProcess_WriteBlobsToTemporaryFilesForIndexedDB
    , NetworkContentRuleListManager_AddContentRuleLists
    , NetworkContentRuleListManager_Remove
    , NetworkContentRuleListManager_RemoveAllContentRuleLists
    , NetworkContentRuleListManager_RemoveContentRuleList
    , NetworkMDNSRegister_RegisterMDNSName
    , NetworkMDNSRegister_UnregisterMDNSNames
    , NetworkProcessConnection_AllCookiesDeleted
    , NetworkProcessConnection_BroadcastConsoleMessage
    , NetworkProcessConnection_CheckProcessLocalPortForActivity
    , NetworkProcessConnection_ConnectToRTCDataChannelRemoteSource
    , NetworkProcessConnection_CookieAcceptPolicyChanged
    , NetworkProcessConnection_CookiesAdded
    , NetworkProcessConnection_CookiesDeleted
    , NetworkProcessConnection_DidCacheResource
    , NetworkProcessConnection_DidFinishPingLoad
    , NetworkProcessConnection_DidFinishPreconnection
    , NetworkProcessConnection_MessagesAvailableForPort
    , NetworkProcessConnection_SetOnLineState
    , NetworkProcessProxy_ContentExtensionRules
    , NetworkProcessProxy_DeleteWebsiteDataInUIProcessForRegistrableDomains
    , NetworkProcessProxy_DidCommitCrossSiteLoadWithDataTransferFromPrevalentResource
    , NetworkProcessProxy_DidExceedMemoryLimit
    , NetworkProcessProxy_DidNegotiateModernTLS
    , NetworkProcessProxy_DidReceiveAuthenticationChallenge
    , NetworkProcessProxy_EndServiceWorkerBackgroundProcessing
    , NetworkProcessProxy_EstablishWorkerContextConnectionToNetworkProcess
    , NetworkProcessProxy_GetAppBoundDomains
    , NetworkProcessProxy_GetWindowSceneIdentifierForPaymentPresentation
    , NetworkProcessProxy_LogDiagnosticMessage
    , NetworkProcessProxy_LogDiagnosticMessageWithResult
    , NetworkProcessProxy_LogDiagnosticMessageWithValue
    , NetworkProcessProxy_LogTestingEvent
    , NetworkProcessProxy_NegotiatedLegacyTLS
    , NetworkProcessProxy_NotifyResourceLoadStatisticsProcessed
    , NetworkProcessProxy_NotifyWebsiteDataDeletionForRegistrableDomainsFinished
    , NetworkProcessProxy_NotifyWebsiteDataScanForRegistrableDomainsFinished
    , NetworkProcessProxy_RegisterServiceWorkerClientProcess
    , NetworkProcessProxy_RequestStorageAccessConfirm
    , NetworkProcessProxy_RequestStorageSpace
    , NetworkProcessProxy_ResourceLoadDidCompleteWithError
    , NetworkProcessProxy_ResourceLoadDidPerformHTTPRedirection
    , NetworkProcessProxy_ResourceLoadDidReceiveChallenge
    , NetworkProcessProxy_ResourceLoadDidReceiveResponse
    , NetworkProcessProxy_ResourceLoadDidSendRequest
    , NetworkProcessProxy_RetrieveCacheStorageParameters
    , NetworkProcessProxy_SetDomainsWithCrossPageStorageAccess
    , NetworkProcessProxy_SetDomainsWithUserInteraction
    , NetworkProcessProxy_SetWebProcessHasUploads
    , NetworkProcessProxy_StartServiceWorkerBackgroundProcessing
    , NetworkProcessProxy_TerminateUnresponsiveServiceWorkerProcesses
    , NetworkProcessProxy_TerminateWebProcess
    , NetworkProcessProxy_TriggerBrowsingContextGroupSwitchForNavigation
    , NetworkProcessProxy_UnregisterServiceWorkerClientProcess
    , NetworkProcessProxy_WorkerContextConnectionNoLongerNeeded
    , NetworkProcess_AddWebPageNetworkParameters
    , NetworkProcess_AddWebsiteDataStore
    , NetworkProcess_AllowSpecificHTTPSCertificateForHost
    , NetworkProcess_AllowTLSCertificateChainForLocalPCMTesting
    , NetworkProcess_AppPrivacyReportTestingData
    , NetworkProcess_ApplicationDidEnterBackground
    , NetworkProcess_ApplicationWillEnterForeground
    , NetworkProcess_CancelDownload
    , NetworkProcess_ClearAppBoundSession
    , NetworkProcess_ClearAppPrivacyReportTestingData
    , NetworkProcess_ClearBundleIdentifier
    , NetworkProcess_ClearCachedCredentials
    , NetworkProcess_ClearPrevalentResource
    , NetworkProcess_ClearPrivateClickMeasurement
    , NetworkProcess_ClearServiceWorkerEntitlementOverride
    , NetworkProcess_ClearStorage
    , NetworkProcess_ClearUserInteraction
    , NetworkProcess_ContinueWillSendRequest
    , NetworkProcess_CountNonDefaultSessionSets
    , NetworkProcess_CreateNetworkConnectionToWebProcess
    , NetworkProcess_DeleteCookiesForTesting
    , NetworkProcess_DeletePushAndNotificationRegistration
    , NetworkProcess_DeleteWebsiteData
    , NetworkProcess_DeleteWebsiteDataForOrigins
    , NetworkProcess_DestroySession
    , NetworkProcess_DidCommitCrossSiteLoadWithDataTransfer
    , NetworkProcess_DisableServiceWorkerEntitlement
    , NetworkProcess_DomainIDExistsInDatabase
    , NetworkProcess_DownloadRequest
    , NetworkProcess_DumpPrivateClickMeasurement
    , NetworkProcess_DumpResourceLoadStatistics
    , NetworkProcess_FetchWebsiteData
    , NetworkProcess_FlushCookies
    , NetworkProcess_GetAllStorageAccessEntries
    , NetworkProcess_GetLocalStorageOriginDetails
    , NetworkProcess_GetOriginsWithPushAndNotificationPermissions
    , NetworkProcess_GetResourceLoadStatisticsDataSummary
    , NetworkProcess_HadUserInteraction
    , NetworkProcess_HasAppBoundSession
    , NetworkProcess_HasIsolatedSession
    , NetworkProcess_HasLocalStorage
    , NetworkProcess_InitializeNetworkProcess
    , NetworkProcess_InsertExpiredStatisticForTesting
    , NetworkProcess_IsGrandfathered
    , NetworkProcess_IsPrevalentResource
    , NetworkProcess_IsRegisteredAsRedirectingTo
    , NetworkProcess_IsRegisteredAsSubFrameUnder
    , NetworkProcess_IsRegisteredAsSubresourceUnder
    , NetworkProcess_IsRelationshipOnlyInDatabaseOnce
    , NetworkProcess_IsResourceLoadStatisticsEphemeral
    , NetworkProcess_IsVeryPrevalentResource
    , NetworkProcess_LogFrameNavigation
    , NetworkProcess_LogUserInteraction
    , NetworkProcess_MarkAttributedPrivateClickMeasurementsAsExpiredForTesting
    , NetworkProcess_MarkPrivateClickMeasurementsAsExpiredForTesting
    , NetworkProcess_MergeStatisticForTesting
    , NetworkProcess_NotifyPreferencesChanged
    , NetworkProcess_PreconnectTo
    , NetworkProcess_PrefetchDNS
    , NetworkProcess_PrepareToSuspend
    , NetworkProcess_ProcessDidResume
    , NetworkProcess_ProcessPushMessage
    , NetworkProcess_PublishDownloadProgress
    , NetworkProcess_RegisterURLSchemeAsBypassingContentSecurityPolicy
    , NetworkProcess_RegisterURLSchemeAsLocal
    , NetworkProcess_RegisterURLSchemeAsNoAccess
    , NetworkProcess_RegisterURLSchemeAsSecure
    , NetworkProcess_RemoveWebPageNetworkParameters
    , NetworkProcess_RenameOriginInWebsiteData
    , NetworkProcess_ResetCacheMaxAgeCapForPrevalentResources
    , NetworkProcess_ResetCrossSiteLoadsWithLinkDecorationForTesting
    , NetworkProcess_ResetParametersToDefaultValues
    , NetworkProcess_ResetQuota
    , NetworkProcess_ResumeDownload
    , NetworkProcess_ScheduleClearInMemoryAndPersistent
    , NetworkProcess_ScheduleCookieBlockingUpdate
    , NetworkProcess_ScheduleStatisticsAndDataRecordsProcessing
    , NetworkProcess_SetAgeCapForClientSideCookies
    , NetworkProcess_SetAppBoundDomainsForResourceLoadStatistics
    , NetworkProcess_SetCacheMaxAgeCapForPrevalentResources
    , NetworkProcess_SetCacheModel
    , NetworkProcess_SetCacheStorageParameters
    , NetworkProcess_SetCrossSiteLoadWithLinkDecorationForTesting
    , NetworkProcess_SetFirstPartyHostCNAMEDomainForTesting
    , NetworkProcess_SetFirstPartyWebsiteDataRemovalModeForTesting
    , NetworkProcess_SetGrandfathered
    , NetworkProcess_SetGrandfatheringTime
    , NetworkProcess_SetIgnoreTLSErrors
    , NetworkProcess_SetIsRunningResourceLoadStatisticsTest
    , NetworkProcess_SetLastSeen
    , NetworkProcess_SetMaxStatisticsEntries
    , NetworkProcess_SetMinimumTimeBetweenDataRecordsRemoval
    , NetworkProcess_SetNetworkProxySettings
    , NetworkProcess_SetNotifyPagesWhenDataRecordsWereScanned
    , NetworkProcess_SetPCMFraudPreventionValuesForTesting
    , NetworkProcess_SetPersistentCredentialStorageEnabled
    , NetworkProcess_SetPrevalentResource
    , NetworkProcess_SetPrevalentResourceForDebugMode
    , NetworkProcess_SetPrivateClickMeasurementAppBundleIDForTesting
    , NetworkProcess_SetPrivateClickMeasurementAttributionReportURLsForTesting
    , NetworkProcess_SetPrivateClickMeasurementDebugMode
    , NetworkProcess_SetPrivateClickMeasurementEphemeralMeasurementForTesting
    , NetworkProcess_SetPrivateClickMeasurementOverrideTimerForTesting
    , NetworkProcess_SetPrivateClickMeasurementTokenPublicKeyURLForTesting
    , NetworkProcess_SetPrivateClickMeasurementTokenSignatureURLForTesting
    , NetworkProcess_SetPruneEntriesDownTo
    , NetworkProcess_SetQOS
    , NetworkProcess_SetResourceLoadStatisticsDebugMode
    , NetworkProcess_SetResourceLoadStatisticsEnabled
    , NetworkProcess_SetResourceLoadStatisticsLogTestingEvent
    , NetworkProcess_SetSessionIsControlledByAutomation
    , NetworkProcess_SetShouldClassifyResourcesBeforeDataRecordsRemoval
    , NetworkProcess_SetShouldDowngradeReferrerForTesting
    , NetworkProcess_SetShouldEnbleSameSiteStrictEnforcementForTesting
    , NetworkProcess_SetSubframeUnderTopFrameDomain
    , NetworkProcess_SetSubresourceUnderTopFrameDomain
    , NetworkProcess_SetSubresourceUniqueRedirectFrom
    , NetworkProcess_SetSubresourceUniqueRedirectTo
    , NetworkProcess_SetThirdPartyCNAMEDomainForTesting
    , NetworkProcess_SetThirdPartyCookieBlockingMode
    , NetworkProcess_SetTimeToLiveUserInteraction
    , NetworkProcess_SetToSameSiteStrictCookiesForTesting
    , NetworkProcess_SetTopFrameUniqueRedirectFrom
    , NetworkProcess_SetTopFrameUniqueRedirectTo
    , NetworkProcess_SetVeryPrevalentResource
    , NetworkProcess_SimulateResourceLoadStatisticsSessionRestart
    , NetworkProcess_StatisticsDatabaseHasAllTables
    , NetworkProcess_StorePrivateClickMeasurement
    , NetworkProcess_SyncLocalStorage
    , NetworkProcess_UpdateBundleIdentifier
    , NetworkProcess_UpdatePrevalentDomainsToBlockCookiesFor
    , NetworkProcess_UserPreferredLanguagesChanged
    , NetworkRTCMonitor_StartUpdatingIfNeeded
    , NetworkRTCMonitor_StopUpdating
    , NetworkRTCProvider_CloseSocket
    , NetworkRTCProvider_CreateClientTCPSocket
    , NetworkRTCProvider_CreateResolver
    , NetworkRTCProvider_CreateServerTCPSocket
    , NetworkRTCProvider_CreateUDPSocket
    , NetworkRTCProvider_SendToSocket
    , NetworkRTCProvider_SetPlatformTCPSocketsEnabled
    , NetworkRTCProvider_SetPlatformUDPSocketsEnabled
    , NetworkRTCProvider_SetSocketOption
    , NetworkRTCProvider_StopResolver
    , NetworkRTCProvider_WrapNewTCPConnection
    , NetworkResourceLoader_ContinueDidReceiveResponse
    , NetworkResourceLoader_ContinueWillSendRequest
    , NetworkSocketChannel_Close
    , NetworkSocketChannel_SendData
    , NetworkSocketChannel_SendString
    , NetworkSocketStream_Close
    , NetworkSocketStream_SendData
    , NetworkSocketStream_SendHandshake
    , NetworkStorageManager_CloseAccessHandle
    , NetworkStorageManager_CloseHandle
    , NetworkStorageManager_CreateSyncAccessHandle
    , NetworkStorageManager_FileSystemGetDirectory
    , NetworkStorageManager_GetDirectoryHandle
    , NetworkStorageManager_GetFile
    , NetworkStorageManager_GetFileHandle
    , NetworkStorageManager_GetHandle
    , NetworkStorageManager_GetHandleNames
    , NetworkStorageManager_IsSameEntry
    , NetworkStorageManager_Move
    , NetworkStorageManager_Persist
    , NetworkStorageManager_Persisted
    , NetworkStorageManager_RemoveEntry
    , NetworkStorageManager_Resolve
    , NotificationManagerMessageHandler_CancelNotification
    , NotificationManagerMessageHandler_ClearNotifications
    , NotificationManagerMessageHandler_DidDestroyNotification
    , NotificationManagerMessageHandler_RequestSystemNotificationPermission
    , NotificationManagerMessageHandler_ShowNotification
    , PlatformXRSystemProxy_SessionDidEnd
    , PlatformXRSystem_EnumerateImmersiveXRDevices
    , PlatformXRSystem_InitializeTrackingAndRendering
    , PlatformXRSystem_RequestFrame
    , PlatformXRSystem_ShutDownTrackingAndRendering
    , PlatformXRSystem_SubmitFrame
    , RTCDataChannelRemoteManagerProxy_BufferedAmountIsDecreasing
    , RTCDataChannelRemoteManagerProxy_ChangeReadyState
    , RTCDataChannelRemoteManagerProxy_Close
    , RTCDataChannelRemoteManagerProxy_DetectError
    , RTCDataChannelRemoteManagerProxy_ReceiveData
    , RTCDataChannelRemoteManagerProxy_SendData
    , RTCDataChannelRemoteManager_BufferedAmountIsDecreasing
    , RTCDataChannelRemoteManager_ChangeReadyState
    , RTCDataChannelRemoteManager_Close
    , RTCDataChannelRemoteManager_DetectError
    , RTCDataChannelRemoteManager_ReceiveData
    , RTCDataChannelRemoteManager_SendData
    , RemoteAudioDestinationManager_AudioSamplesStorageChanged
    , RemoteAudioDestinationManager_DeleteAudioDestination
    , RemoteAudioDestinationManager_StartAudioDestination
    , RemoteAudioDestinationManager_StopAudioDestination
    , RemoteAudioHardwareListener_AudioHardwareDidBecomeActive
    , RemoteAudioHardwareListener_AudioHardwareDidBecomeInactive
    , RemoteAudioHardwareListener_AudioOutputDeviceChanged
    , RemoteAudioMediaStreamTrackRendererInternalUnitManager_CreateUnit
    , RemoteAudioMediaStreamTrackRendererInternalUnitManager_DeleteUnit
    , RemoteAudioMediaStreamTrackRendererInternalUnitManager_SetAudioOutputDevice
    , RemoteAudioMediaStreamTrackRendererInternalUnitManager_StartUnit
    , RemoteAudioMediaStreamTrackRendererInternalUnitManager_StopUnit
    , RemoteAudioSessionProxy_SetCategory
    , RemoteAudioSessionProxy_SetIsPlayingToBluetoothOverride
    , RemoteAudioSessionProxy_SetPreferredBufferSize
    , RemoteAudioSession_BeginInterruption
    , RemoteAudioSession_ConfigurationChanged
    , RemoteAudioSession_EndInterruption
    , RemoteAudioSourceProviderManager_AudioSamplesAvailable
    , RemoteAudioSourceProviderManager_AudioStorageChanged
    , RemoteBindGroupLayout_SetLabel
    , RemoteBindGroup_SetLabel
    , RemoteBuffer_Destroy
    , RemoteBuffer_SetLabel
    , RemoteBuffer_Unmap
    , RemoteCDMInstanceProxy_InitializeWithConfiguration
    , RemoteCDMInstanceProxy_SetServerCertificate
    , RemoteCDMInstanceProxy_SetStorageDirectory
    , RemoteCDMInstanceSessionProxy_CloseSession
    , RemoteCDMInstanceSessionProxy_DisplayIDChanged
    , RemoteCDMInstanceSessionProxy_LoadSession
    , RemoteCDMInstanceSessionProxy_RemoveSessionData
    , RemoteCDMInstanceSessionProxy_RequestLicense
    , RemoteCDMInstanceSessionProxy_StoreRecordOfKeyUsage
    , RemoteCDMInstanceSessionProxy_UpdateLicense
    , RemoteCDMInstanceSession_SendMessage
    , RemoteCDMInstanceSession_SessionIdChanged
    , RemoteCDMInstanceSession_UpdateKeyStatuses
    , RemoteCDMInstance_UnrequestedInitializationDataReceived
    , RemoteCDMProxy_GetSupportedConfiguration
    , RemoteCDMProxy_LoadAndInitialize
    , RemoteCommandBuffer_SetLabel
    , RemoteCommandEncoder_BeginComputePass
    , RemoteCommandEncoder_BeginRenderPass
    , RemoteCommandEncoder_CopyBufferToBuffer
    , RemoteCommandEncoder_CopyBufferToTexture
    , RemoteCommandEncoder_CopyTextureToBuffer
    , RemoteCommandEncoder_CopyTextureToTexture
    , RemoteCommandEncoder_FillBuffer
    , RemoteCommandEncoder_Finish
    , RemoteCommandEncoder_InsertDebugMarker
    , RemoteCommandEncoder_PopDebugGroup
    , RemoteCommandEncoder_PushDebugGroup
    , RemoteCommandEncoder_ResolveQuerySet
    , RemoteCommandEncoder_SetLabel
    , RemoteCommandEncoder_WriteTimestamp
    , RemoteComputePassEncoder_BeginPipelineStatisticsQuery
    , RemoteComputePassEncoder_Dispatch
    , RemoteComputePassEncoder_DispatchIndirect
    , RemoteComputePassEncoder_EndPass
    , RemoteComputePassEncoder_EndPipelineStatisticsQuery
    , RemoteComputePassEncoder_InsertDebugMarker
    , RemoteComputePassEncoder_PopDebugGroup
    , RemoteComputePassEncoder_PushDebugGroup
    , RemoteComputePassEncoder_SetBindGroup
    , RemoteComputePassEncoder_SetLabel
    , RemoteComputePassEncoder_SetPipeline
    , RemoteComputePipeline_GetBindGroupLayout
    , RemoteComputePipeline_SetLabel
    , RemoteDevice_CreateBindGroup
    , RemoteDevice_CreateBindGroupLayout
    , RemoteDevice_CreateBuffer
    , RemoteDevice_CreateCommandEncoder
    , RemoteDevice_CreateComputePipeline
    , RemoteDevice_CreatePipelineLayout
    , RemoteDevice_CreateQuerySet
    , RemoteDevice_CreateRenderBundleEncoder
    , RemoteDevice_CreateRenderPipeline
    , RemoteDevice_CreateSampler
    , RemoteDevice_CreateShaderModule
    , RemoteDevice_CreateTexture
    , RemoteDevice_Destroy
    , RemoteDevice_ImportExternalTexture
    , RemoteDevice_PushErrorScope
    , RemoteDevice_SetLabel
    , RemoteDisplayListRecorder_ApplyDeviceScaleFactor
    , RemoteDisplayListRecorder_ApplyFillPattern
    , RemoteDisplayListRecorder_ApplyStrokePattern
    , RemoteDisplayListRecorder_BeginClipToDrawingCommands
    , RemoteDisplayListRecorder_BeginTransparencyLayer
    , RemoteDisplayListRecorder_ClearRect
    , RemoteDisplayListRecorder_ClearShadow
    , RemoteDisplayListRecorder_Clip
    , RemoteDisplayListRecorder_ClipOut
    , RemoteDisplayListRecorder_ClipOutToPath
    , RemoteDisplayListRecorder_ClipPath
    , RemoteDisplayListRecorder_ClipToImageBuffer
    , RemoteDisplayListRecorder_ConcatenateCTM
    , RemoteDisplayListRecorder_DrawDotsForDocumentMarker
    , RemoteDisplayListRecorder_DrawEllipse
    , RemoteDisplayListRecorder_DrawFocusRingPath
    , RemoteDisplayListRecorder_DrawFocusRingRects
    , RemoteDisplayListRecorder_DrawGlyphs
    , RemoteDisplayListRecorder_DrawImageBuffer
    , RemoteDisplayListRecorder_DrawLine
    , RemoteDisplayListRecorder_DrawLinesForText
    , RemoteDisplayListRecorder_DrawNativeImage
    , RemoteDisplayListRecorder_DrawPath
    , RemoteDisplayListRecorder_DrawPattern
    , RemoteDisplayListRecorder_DrawRect
    , RemoteDisplayListRecorder_EndClipToDrawingCommands
    , RemoteDisplayListRecorder_EndTransparencyLayer
    , RemoteDisplayListRecorder_FillArc
    , RemoteDisplayListRecorder_FillBezierCurve
    , RemoteDisplayListRecorder_FillCompositedRect
    , RemoteDisplayListRecorder_FillEllipse
    , RemoteDisplayListRecorder_FillLine
    , RemoteDisplayListRecorder_FillPath
    , RemoteDisplayListRecorder_FillQuadCurve
    , RemoteDisplayListRecorder_FillRect
    , RemoteDisplayListRecorder_FillRectWithColor
    , RemoteDisplayListRecorder_FillRectWithGradient
    , RemoteDisplayListRecorder_FillRectWithRoundedHole
    , RemoteDisplayListRecorder_FillRoundedRect
    , RemoteDisplayListRecorder_FlushContext
    , RemoteDisplayListRecorder_GetPixelBuffer
    , RemoteDisplayListRecorder_PaintFrameForMedia
    , RemoteDisplayListRecorder_PutPixelBuffer
    , RemoteDisplayListRecorder_Restore
    , RemoteDisplayListRecorder_Rotate
    , RemoteDisplayListRecorder_Save
    , RemoteDisplayListRecorder_Scale
    , RemoteDisplayListRecorder_SetCTM
    , RemoteDisplayListRecorder_SetInlineFillColor
    , RemoteDisplayListRecorder_SetInlineStrokeColor
    , RemoteDisplayListRecorder_SetLineCap
    , RemoteDisplayListRecorder_SetLineDash
    , RemoteDisplayListRecorder_SetLineJoin
    , RemoteDisplayListRecorder_SetMiterLimit
    , RemoteDisplayListRecorder_SetState
    , RemoteDisplayListRecorder_SetStrokeThickness
    , RemoteDisplayListRecorder_StrokeArc
    , RemoteDisplayListRecorder_StrokeBezierCurve
    , RemoteDisplayListRecorder_StrokeEllipse
    , RemoteDisplayListRecorder_StrokeLine
    , RemoteDisplayListRecorder_StrokePath
    , RemoteDisplayListRecorder_StrokeQuadCurve
    , RemoteDisplayListRecorder_StrokeRect
    , RemoteDisplayListRecorder_Translate
    , RemoteExternalTexture_SetLabel
    , RemoteGraphicsContextGLProxy_WasChanged
    , RemoteGraphicsContextGLProxy_WasCreated
    , RemoteGraphicsContextGLProxy_WasLost
    , RemoteGraphicsContextGL_ActiveTexture
    , RemoteGraphicsContextGL_AttachShader
    , RemoteGraphicsContextGL_BeginQuery
    , RemoteGraphicsContextGL_BeginTransformFeedback
    , RemoteGraphicsContextGL_BindAttribLocation
    , RemoteGraphicsContextGL_BindBuffer
    , RemoteGraphicsContextGL_BindBufferBase
    , RemoteGraphicsContextGL_BindBufferRange
    , RemoteGraphicsContextGL_BindFramebuffer
    , RemoteGraphicsContextGL_BindRenderbuffer
    , RemoteGraphicsContextGL_BindSampler
    , RemoteGraphicsContextGL_BindTexture
    , RemoteGraphicsContextGL_BindTransformFeedback
    , RemoteGraphicsContextGL_BindVertexArray
    , RemoteGraphicsContextGL_BlendColor
    , RemoteGraphicsContextGL_BlendEquation
    , RemoteGraphicsContextGL_BlendEquationSeparate
    , RemoteGraphicsContextGL_BlendFunc
    , RemoteGraphicsContextGL_BlendFuncSeparate
    , RemoteGraphicsContextGL_BlitFramebuffer
    , RemoteGraphicsContextGL_BufferData0
    , RemoteGraphicsContextGL_BufferData1
    , RemoteGraphicsContextGL_BufferSubData
    , RemoteGraphicsContextGL_Clear
    , RemoteGraphicsContextGL_ClearBufferfi
    , RemoteGraphicsContextGL_ClearBufferfv
    , RemoteGraphicsContextGL_ClearBufferiv
    , RemoteGraphicsContextGL_ClearBufferuiv
    , RemoteGraphicsContextGL_ClearColor
    , RemoteGraphicsContextGL_ClearDepth
    , RemoteGraphicsContextGL_ClearStencil
    , RemoteGraphicsContextGL_ColorMask
    , RemoteGraphicsContextGL_CompileShader
    , RemoteGraphicsContextGL_CompressedTexImage2D0
    , RemoteGraphicsContextGL_CompressedTexImage2D1
    , RemoteGraphicsContextGL_CompressedTexImage3D0
    , RemoteGraphicsContextGL_CompressedTexImage3D1
    , RemoteGraphicsContextGL_CompressedTexSubImage2D0
    , RemoteGraphicsContextGL_CompressedTexSubImage2D1
    , RemoteGraphicsContextGL_CompressedTexSubImage3D0
    , RemoteGraphicsContextGL_CompressedTexSubImage3D1
    , RemoteGraphicsContextGL_CopyBufferSubData
    , RemoteGraphicsContextGL_CopyTexImage2D
    , RemoteGraphicsContextGL_CopyTexSubImage2D
    , RemoteGraphicsContextGL_CopyTexSubImage3D
    , RemoteGraphicsContextGL_CullFace
    , RemoteGraphicsContextGL_DeleteBuffer
    , RemoteGraphicsContextGL_DeleteFramebuffer
    , RemoteGraphicsContextGL_DeleteProgram
    , RemoteGraphicsContextGL_DeleteQuery
    , RemoteGraphicsContextGL_DeleteRenderbuffer
    , RemoteGraphicsContextGL_DeleteSampler
    , RemoteGraphicsContextGL_DeleteShader
    , RemoteGraphicsContextGL_DeleteSync
    , RemoteGraphicsContextGL_DeleteTexture
    , RemoteGraphicsContextGL_DeleteTransformFeedback
    , RemoteGraphicsContextGL_DeleteVertexArray
    , RemoteGraphicsContextGL_DepthFunc
    , RemoteGraphicsContextGL_DepthMask
    , RemoteGraphicsContextGL_DepthRange
    , RemoteGraphicsContextGL_DetachShader
    , RemoteGraphicsContextGL_Disable
    , RemoteGraphicsContextGL_DisableVertexAttribArray
    , RemoteGraphicsContextGL_DrawArrays
    , RemoteGraphicsContextGL_DrawArraysInstanced
    , RemoteGraphicsContextGL_DrawBuffers
    , RemoteGraphicsContextGL_DrawBuffersEXT
    , RemoteGraphicsContextGL_DrawElements
    , RemoteGraphicsContextGL_DrawElementsInstanced
    , RemoteGraphicsContextGL_DrawRangeElements
    , RemoteGraphicsContextGL_Enable
    , RemoteGraphicsContextGL_EnableVertexAttribArray
    , RemoteGraphicsContextGL_EndQuery
    , RemoteGraphicsContextGL_EndTransformFeedback
    , RemoteGraphicsContextGL_EnsureExtensionEnabled
    , RemoteGraphicsContextGL_Finish
    , RemoteGraphicsContextGL_Flush
    , RemoteGraphicsContextGL_FramebufferRenderbuffer
    , RemoteGraphicsContextGL_FramebufferTexture2D
    , RemoteGraphicsContextGL_FramebufferTextureLayer
    , RemoteGraphicsContextGL_FrontFace
    , RemoteGraphicsContextGL_GenerateMipmap
    , RemoteGraphicsContextGL_Hint
    , RemoteGraphicsContextGL_InvalidateFramebuffer
    , RemoteGraphicsContextGL_InvalidateSubFramebuffer
    , RemoteGraphicsContextGL_LineWidth
    , RemoteGraphicsContextGL_LinkProgram
    , RemoteGraphicsContextGL_MultiDrawArraysANGLE
    , RemoteGraphicsContextGL_MultiDrawArraysInstancedANGLE
    , RemoteGraphicsContextGL_MultiDrawElementsANGLE
    , RemoteGraphicsContextGL_MultiDrawElementsInstancedANGLE
    , RemoteGraphicsContextGL_NotifyMarkContextChanged
    , RemoteGraphicsContextGL_PauseTransformFeedback
    , RemoteGraphicsContextGL_PixelStorei
    , RemoteGraphicsContextGL_PolygonOffset
    , RemoteGraphicsContextGL_ReadBuffer
    , RemoteGraphicsContextGL_ReadnPixels1
    , RemoteGraphicsContextGL_RenderbufferStorage
    , RemoteGraphicsContextGL_RenderbufferStorageMultisample
    , RemoteGraphicsContextGL_Reshape
    , RemoteGraphicsContextGL_ResumeTransformFeedback
    , RemoteGraphicsContextGL_SampleCoverage
    , RemoteGraphicsContextGL_SamplerParameterf
    , RemoteGraphicsContextGL_SamplerParameteri
    , RemoteGraphicsContextGL_Scissor
    , RemoteGraphicsContextGL_ShaderSource
    , RemoteGraphicsContextGL_SimulateEventForTesting
    , RemoteGraphicsContextGL_StencilFunc
    , RemoteGraphicsContextGL_StencilFuncSeparate
    , RemoteGraphicsContextGL_StencilMask
    , RemoteGraphicsContextGL_StencilMaskSeparate
    , RemoteGraphicsContextGL_StencilOp
    , RemoteGraphicsContextGL_StencilOpSeparate
    , RemoteGraphicsContextGL_SynthesizeGLError
    , RemoteGraphicsContextGL_TexImage2D0
    , RemoteGraphicsContextGL_TexImage2D1
    , RemoteGraphicsContextGL_TexImage3D0
    , RemoteGraphicsContextGL_TexImage3D1
    , RemoteGraphicsContextGL_TexParameterf
    , RemoteGraphicsContextGL_TexParameteri
    , RemoteGraphicsContextGL_TexStorage2D
    , RemoteGraphicsContextGL_TexStorage3D
    , RemoteGraphicsContextGL_TexSubImage2D0
    , RemoteGraphicsContextGL_TexSubImage2D1
    , RemoteGraphicsContextGL_TexSubImage3D0
    , RemoteGraphicsContextGL_TexSubImage3D1
    , RemoteGraphicsContextGL_TransformFeedbackVaryings
    , RemoteGraphicsContextGL_Uniform1f
    , RemoteGraphicsContextGL_Uniform1fv
    , RemoteGraphicsContextGL_Uniform1i
    , RemoteGraphicsContextGL_Uniform1iv
    , RemoteGraphicsContextGL_Uniform1ui
    , RemoteGraphicsContextGL_Uniform1uiv
    , RemoteGraphicsContextGL_Uniform2f
    , RemoteGraphicsContextGL_Uniform2fv
    , RemoteGraphicsContextGL_Uniform2i
    , RemoteGraphicsContextGL_Uniform2iv
    , RemoteGraphicsContextGL_Uniform2ui
    , RemoteGraphicsContextGL_Uniform2uiv
    , RemoteGraphicsContextGL_Uniform3f
    , RemoteGraphicsContextGL_Uniform3fv
    , RemoteGraphicsContextGL_Uniform3i
    , RemoteGraphicsContextGL_Uniform3iv
    , RemoteGraphicsContextGL_Uniform3ui
    , RemoteGraphicsContextGL_Uniform3uiv
    , RemoteGraphicsContextGL_Uniform4f
    , RemoteGraphicsContextGL_Uniform4fv
    , RemoteGraphicsContextGL_Uniform4i
    , RemoteGraphicsContextGL_Uniform4iv
    , RemoteGraphicsContextGL_Uniform4ui
    , RemoteGraphicsContextGL_Uniform4uiv
    , RemoteGraphicsContextGL_UniformBlockBinding
    , RemoteGraphicsContextGL_UniformMatrix2fv
    , RemoteGraphicsContextGL_UniformMatrix2x3fv
    , RemoteGraphicsContextGL_UniformMatrix2x4fv
    , RemoteGraphicsContextGL_UniformMatrix3fv
    , RemoteGraphicsContextGL_UniformMatrix3x2fv
    , RemoteGraphicsContextGL_UniformMatrix3x4fv
    , RemoteGraphicsContextGL_UniformMatrix4fv
    , RemoteGraphicsContextGL_UniformMatrix4x2fv
    , RemoteGraphicsContextGL_UniformMatrix4x3fv
    , RemoteGraphicsContextGL_UseProgram
    , RemoteGraphicsContextGL_ValidateProgram
    , RemoteGraphicsContextGL_VertexAttrib1f
    , RemoteGraphicsContextGL_VertexAttrib1fv
    , RemoteGraphicsContextGL_VertexAttrib2f
    , RemoteGraphicsContextGL_VertexAttrib2fv
    , RemoteGraphicsContextGL_VertexAttrib3f
    , RemoteGraphicsContextGL_VertexAttrib3fv
    , RemoteGraphicsContextGL_VertexAttrib4f
    , RemoteGraphicsContextGL_VertexAttrib4fv
    , RemoteGraphicsContextGL_VertexAttribDivisor
    , RemoteGraphicsContextGL_VertexAttribI4i
    , RemoteGraphicsContextGL_VertexAttribI4iv
    , RemoteGraphicsContextGL_VertexAttribI4ui
    , RemoteGraphicsContextGL_VertexAttribI4uiv
    , RemoteGraphicsContextGL_VertexAttribIPointer
    , RemoteGraphicsContextGL_VertexAttribPointer
    , RemoteGraphicsContextGL_Viewport
    , RemoteGraphicsContextGL_WaitSync
    , RemoteLegacyCDMProxy_SetPlayerId
    , RemoteLegacyCDMSessionProxy_ReleaseKeys
    , RemoteLegacyCDMSession_SendError
    , RemoteLegacyCDMSession_SendMessage
    , RemoteMediaEngineConfigurationFactoryProxy_CreateDecodingConfiguration
    , RemoteMediaEngineConfigurationFactoryProxy_CreateEncodingConfiguration
    , RemoteMediaPlayerManagerProxy_ClearMediaCache
    , RemoteMediaPlayerManagerProxy_ClearMediaCacheForOrigins
    , RemoteMediaPlayerManagerProxy_CreateMediaPlayer
    , RemoteMediaPlayerManagerProxy_DeleteMediaPlayer
    , RemoteMediaPlayerProxy_AcceleratedRenderingStateChanged
    , RemoteMediaPlayerProxy_ApplicationDidBecomeActive
    , RemoteMediaPlayerProxy_ApplicationWillResignActive
    , RemoteMediaPlayerProxy_AttemptToDecryptWithInstance
    , RemoteMediaPlayerProxy_AudioTrackSetEnabled
    , RemoteMediaPlayerProxy_BeginSimulatedHDCPError
    , RemoteMediaPlayerProxy_CancelLoad
    , RemoteMediaPlayerProxy_CdmInstanceAttached
    , RemoteMediaPlayerProxy_CdmInstanceDetached
    , RemoteMediaPlayerProxy_CreateAudioSourceProvider
    , RemoteMediaPlayerProxy_DidLoadingProgress
    , RemoteMediaPlayerProxy_EndSimulatedHDCPError
    , RemoteMediaPlayerProxy_KeyAdded
    , RemoteMediaPlayerProxy_Load
    , RemoteMediaPlayerProxy_LoadMediaSource
    , RemoteMediaPlayerProxy_NotifyActiveSourceBuffersChanged
    , RemoteMediaPlayerProxy_NotifyTrackModeChanged
    , RemoteMediaPlayerProxy_Pause
    , RemoteMediaPlayerProxy_PauseAtHostTime
    , RemoteMediaPlayerProxy_PerformTaskAtMediaTime
    , RemoteMediaPlayerProxy_Play
    , RemoteMediaPlayerProxy_PlayAtHostTime
    , RemoteMediaPlayerProxy_PrepareForPlayback
    , RemoteMediaPlayerProxy_PrepareForRendering
    , RemoteMediaPlayerProxy_PrepareToPlay
    , RemoteMediaPlayerProxy_Seek
    , RemoteMediaPlayerProxy_SeekWithTolerance
    , RemoteMediaPlayerProxy_SetBufferingPolicy
    , RemoteMediaPlayerProxy_SetLegacyCDMSession
    , RemoteMediaPlayerProxy_SetMuted
    , RemoteMediaPlayerProxy_SetPageIsVisible
    , RemoteMediaPlayerProxy_SetPitchCorrectionAlgorithm
    , RemoteMediaPlayerProxy_SetPreferredDynamicRangeMode
    , RemoteMediaPlayerProxy_SetPreload
    , RemoteMediaPlayerProxy_SetPreservesPitch
    , RemoteMediaPlayerProxy_SetPrivateBrowsingMode
    , RemoteMediaPlayerProxy_SetRate
    , RemoteMediaPlayerProxy_SetShouldContinueAfterKeyNeeded
    , RemoteMediaPlayerProxy_SetShouldDisableSleep
    , RemoteMediaPlayerProxy_SetShouldEnableAudioSourceProvider
    , RemoteMediaPlayerProxy_SetShouldMaintainAspectRatio
    , RemoteMediaPlayerProxy_SetShouldPlayToPlaybackTarget
    , RemoteMediaPlayerProxy_SetVideoFullscreenGravity
    , RemoteMediaPlayerProxy_SetVideoFullscreenMode
    , RemoteMediaPlayerProxy_SetVideoInlineSizeFenced
    , RemoteMediaPlayerProxy_SetVideoPlaybackMetricsUpdateInterval
    , RemoteMediaPlayerProxy_SetVolume
    , RemoteMediaPlayerProxy_SetWirelessPlaybackTarget
    , RemoteMediaPlayerProxy_SetWirelessVideoPlaybackDisabled
    , RemoteMediaPlayerProxy_StartVideoFrameMetadataGathering
    , RemoteMediaPlayerProxy_StopVideoFrameMetadataGathering
    , RemoteMediaPlayerProxy_TextTrackSetMode
    , RemoteMediaPlayerProxy_TracksChanged
    , RemoteMediaPlayerProxy_UpdateVideoFullscreenInlineImage
    , RemoteMediaPlayerProxy_VideoFullscreenStandbyChanged
    , RemoteMediaPlayerProxy_VideoTrackSetSelected
    , RemoteMediaRecorderManager_CreateRecorder
    , RemoteMediaRecorderManager_ReleaseRecorder
    , RemoteMediaRecorder_AudioSamplesAvailable
    , RemoteMediaRecorder_AudioSamplesStorageChanged
    , RemoteMediaRecorder_FetchData
    , RemoteMediaRecorder_Pause
    , RemoteMediaRecorder_Resume
    , RemoteMediaRecorder_StopRecording
    , RemoteMediaRecorder_VideoSampleAvailable
    , RemoteMediaResourceManager_AccessControlCheckFailed
    , RemoteMediaResourceManager_DataReceived
    , RemoteMediaResourceManager_DataSent
    , RemoteMediaResourceManager_LoadFailed
    , RemoteMediaResourceManager_LoadFinished
    , RemoteMediaResourceManager_RedirectReceived
    , RemoteMediaResourceManager_ResponseReceived
    , RemoteMediaSessionCoordinatorProxy_CoordinatePause
    , RemoteMediaSessionCoordinatorProxy_CoordinatePlay
    , RemoteMediaSessionCoordinatorProxy_CoordinateSeekTo
    , RemoteMediaSessionCoordinatorProxy_CoordinateSetTrack
    , RemoteMediaSessionCoordinatorProxy_Join
    , RemoteMediaSessionCoordinatorProxy_Leave
    , RemoteMediaSessionCoordinatorProxy_PlaybackStateChanged
    , RemoteMediaSessionCoordinatorProxy_PositionStateChanged
    , RemoteMediaSessionCoordinatorProxy_ReadyStateChanged
    , RemoteMediaSessionCoordinatorProxy_TrackIdentifierChanged
    , RemoteMediaSessionCoordinator_CoordinatorStateChanged
    , RemoteMediaSessionCoordinator_PauseSession
    , RemoteMediaSessionCoordinator_PlaySession
    , RemoteMediaSessionCoordinator_SeekSessionToTime
    , RemoteMediaSessionCoordinator_SetSessionTrack
    , RemoteMediaSourceProxy_BufferedChanged
    , RemoteMediaSourceProxy_DurationChanged
    , RemoteMediaSourceProxy_SeekCompleted
    , RemoteMediaSourceProxy_SetIsSeeking
    , RemoteMediaSourceProxy_SetReadyState
    , RemoteMediaSourceProxy_SetTimeFudgeFactor
    , RemoteMediaSourceProxy_WaitForSeekCompleted
    , RemotePipelineLayout_SetLabel
    , RemoteQuerySet_Destroy
    , RemoteQuerySet_SetLabel
    , RemoteQueue_CopyExternalImageToTexture
    , RemoteQueue_SetLabel
    , RemoteQueue_Submit
    , RemoteQueue_WriteBuffer
    , RemoteQueue_WriteTexture
    , RemoteRemoteCommandListenerProxy_UpdateSupportedCommands
    , RemoteRemoteCommandListener_DidReceiveRemoteControlCommand
    , RemoteRenderBundleEncoder_Draw
    , RemoteRenderBundleEncoder_DrawIndexed
    , RemoteRenderBundleEncoder_DrawIndexedIndirect
    , RemoteRenderBundleEncoder_DrawIndirect
    , RemoteRenderBundleEncoder_Finish
    , RemoteRenderBundleEncoder_InsertDebugMarker
    , RemoteRenderBundleEncoder_PopDebugGroup
    , RemoteRenderBundleEncoder_PushDebugGroup
    , RemoteRenderBundleEncoder_SetBindGroup
    , RemoteRenderBundleEncoder_SetIndexBuffer
    , RemoteRenderBundleEncoder_SetLabel
    , RemoteRenderBundleEncoder_SetPipeline
    , RemoteRenderBundleEncoder_SetVertexBuffer
    , RemoteRenderBundle_SetLabel
    , RemoteRenderPassEncoder_BeginOcclusionQuery
    , RemoteRenderPassEncoder_BeginPipelineStatisticsQuery
    , RemoteRenderPassEncoder_Draw
    , RemoteRenderPassEncoder_DrawIndexed
    , RemoteRenderPassEncoder_DrawIndexedIndirect
    , RemoteRenderPassEncoder_DrawIndirect
    , RemoteRenderPassEncoder_EndOcclusionQuery
    , RemoteRenderPassEncoder_EndPass
    , RemoteRenderPassEncoder_EndPipelineStatisticsQuery
    , RemoteRenderPassEncoder_ExecuteBundles
    , RemoteRenderPassEncoder_InsertDebugMarker
    , RemoteRenderPassEncoder_PopDebugGroup
    , RemoteRenderPassEncoder_PushDebugGroup
    , RemoteRenderPassEncoder_SetBindGroup
    , RemoteRenderPassEncoder_SetBlendConstant
    , RemoteRenderPassEncoder_SetIndexBuffer
    , RemoteRenderPassEncoder_SetLabel
    , RemoteRenderPassEncoder_SetPipeline
    , RemoteRenderPassEncoder_SetScissorRect
    , RemoteRenderPassEncoder_SetStencilReference
    , RemoteRenderPassEncoder_SetVertexBuffer
    , RemoteRenderPassEncoder_SetViewport
    , RemoteRenderPipeline_GetBindGroupLayout
    , RemoteRenderPipeline_SetLabel
    , RemoteRenderingBackendProxy_DidCreateImageBufferBackend
    , RemoteRenderingBackendProxy_DidCreateWakeUpSemaphoreForDisplayListStream
    , RemoteRenderingBackendProxy_DidFinalizeRenderingUpdate
    , RemoteRenderingBackendProxy_DidFlush
    , RemoteRenderingBackend_CacheFont
    , RemoteRenderingBackend_CacheNativeImage
    , RemoteRenderingBackend_CreateImageBuffer
    , RemoteRenderingBackend_DeleteAllFonts
    , RemoteRenderingBackend_DestroyGetPixelBufferSharedMemory
    , RemoteRenderingBackend_FinalizeRenderingUpdate
    , RemoteRenderingBackend_ReleaseRemoteResource
    , RemoteSampleBufferDisplayLayerManager_CreateLayer
    , RemoteSampleBufferDisplayLayerManager_ReleaseLayer
    , RemoteSampleBufferDisplayLayer_ClearEnqueuedSamples
    , RemoteSampleBufferDisplayLayer_EnqueueSample
    , RemoteSampleBufferDisplayLayer_Flush
    , RemoteSampleBufferDisplayLayer_FlushAndRemoveImage
    , RemoteSampleBufferDisplayLayer_Pause
    , RemoteSampleBufferDisplayLayer_Play
    , RemoteSampleBufferDisplayLayer_SetLogIdentifier
    , RemoteSampleBufferDisplayLayer_UpdateAffineTransform
    , RemoteSampleBufferDisplayLayer_UpdateBoundsAndPosition
    , RemoteSampleBufferDisplayLayer_UpdateDisplayMode
    , RemoteSampler_SetLabel
    , RemoteShaderModule_SetLabel
    , RemoteSourceBufferProxy_Abort
    , RemoteSourceBufferProxy_AddTrackBuffer
    , RemoteSourceBufferProxy_Append
    , RemoteSourceBufferProxy_BufferedSamplesForTrackId
    , RemoteSourceBufferProxy_ClearTrackBuffers
    , RemoteSourceBufferProxy_EnqueuedSamplesForTrackID
    , RemoteSourceBufferProxy_ReenqueueMediaIfNeeded
    , RemoteSourceBufferProxy_RemoveCodedFrames
    , RemoteSourceBufferProxy_RemovedFromMediaSource
    , RemoteSourceBufferProxy_ResetParserState
    , RemoteSourceBufferProxy_ResetTimestampOffsetInTrackBuffers
    , RemoteSourceBufferProxy_ResetTrackBuffers
    , RemoteSourceBufferProxy_SeekToTime
    , RemoteSourceBufferProxy_SetActive
    , RemoteSourceBufferProxy_SetAllTrackBuffersNeedRandomAccess
    , RemoteSourceBufferProxy_SetAppendWindowEnd
    , RemoteSourceBufferProxy_SetAppendWindowStart
    , RemoteSourceBufferProxy_SetGroupStartTimestamp
    , RemoteSourceBufferProxy_SetGroupStartTimestampToEndTimestamp
    , RemoteSourceBufferProxy_SetMediaSourceEnded
    , RemoteSourceBufferProxy_SetMode
    , RemoteSourceBufferProxy_SetReadyState
    , RemoteSourceBufferProxy_SetShouldGenerateTimestamps
    , RemoteSourceBufferProxy_SetTimestampOffset
    , RemoteSourceBufferProxy_StartChangingType
    , RemoteSourceBufferProxy_UpdateTrackIds
    , RemoteTextureView_SetLabel
    , RemoteTexture_CreateView
    , RemoteTexture_Destroy
    , RemoteTexture_SetLabel
    , RemoteWebInspectorUIProxy_Append
    , RemoteWebInspectorUIProxy_BringToFront
    , RemoteWebInspectorUIProxy_FrontendDidClose
    , RemoteWebInspectorUIProxy_FrontendLoaded
    , RemoteWebInspectorUIProxy_OpenURLExternally
    , RemoteWebInspectorUIProxy_Reopen
    , RemoteWebInspectorUIProxy_ResetState
    , RemoteWebInspectorUIProxy_Save
    , RemoteWebInspectorUIProxy_SendMessageToBackend
    , RemoteWebInspectorUIProxy_SetForcedAppearance
    , RemoteWebInspectorUIProxy_SetSheetRect
    , RemoteWebInspectorUIProxy_ShowCertificate
    , RemoteWebInspectorUIProxy_StartWindowDrag
    , RemoteWebInspectorUI_DidAppend
    , RemoteWebInspectorUI_DidSave
    , RemoteWebInspectorUI_Initialize
    , RemoteWebInspectorUI_SendMessageToFrontend
    , RemoteWebInspectorUI_SetDiagnosticLoggingAvailable
    , RemoteWebInspectorUI_ShowConsole
    , RemoteWebInspectorUI_ShowResources
    , RemoteWebInspectorUI_UpdateFindString
    , SampleBufferDisplayLayer_SetDidFail
    , ServiceWorkerFetchTask_DidFail
    , ServiceWorkerFetchTask_DidFinish
    , ServiceWorkerFetchTask_DidNotHandle
    , ServiceWorkerFetchTask_DidReceiveData
    , ServiceWorkerFetchTask_DidReceiveFormData
    , ServiceWorkerFetchTask_DidReceiveRedirectResponse
    , ServiceWorkerFetchTask_DidReceiveResponse
    , SourceBufferPrivateRemote_SourceBufferPrivateAppendComplete
    , SourceBufferPrivateRemote_SourceBufferPrivateAppendError
    , SourceBufferPrivateRemote_SourceBufferPrivateBufferedDirtyChanged
    , SourceBufferPrivateRemote_SourceBufferPrivateDidDropSample
    , SourceBufferPrivateRemote_SourceBufferPrivateDidParseSample
    , SourceBufferPrivateRemote_SourceBufferPrivateDidReceiveInitializationSegment
    , SourceBufferPrivateRemote_SourceBufferPrivateDidReceiveRenderingError
    , SourceBufferPrivateRemote_SourceBufferPrivateDurationChanged
    , SourceBufferPrivateRemote_SourceBufferPrivateHighestPresentationTimestampChanged
    , SourceBufferPrivateRemote_SourceBufferPrivateReportExtraMemoryCost
    , SourceBufferPrivateRemote_SourceBufferPrivateStreamEndedWithDecodeError
    , SpeechRecognitionRealtimeMediaSourceManager_CreateSource
    , SpeechRecognitionRealtimeMediaSourceManager_DeleteSource
    , SpeechRecognitionRealtimeMediaSourceManager_GrantSandboxExtensions
    , SpeechRecognitionRealtimeMediaSourceManager_RevokeSandboxExtensions
    , SpeechRecognitionRealtimeMediaSourceManager_Start
    , SpeechRecognitionRealtimeMediaSourceManager_Stop
    , SpeechRecognitionRemoteRealtimeMediaSourceManager_RemoteAudioSamplesAvailable
    , SpeechRecognitionRemoteRealtimeMediaSourceManager_RemoteCaptureFailed
    , SpeechRecognitionRemoteRealtimeMediaSourceManager_RemoteSourceStopped
    , SpeechRecognitionRemoteRealtimeMediaSourceManager_SetStorage
    , SpeechRecognitionServer_Abort
    , SpeechRecognitionServer_Invalidate
    , SpeechRecognitionServer_Start
    , SpeechRecognitionServer_Stop
    , StorageAreaMap_ClearCache
    , StorageAreaMap_DidClear
    , StorageAreaMap_DidRemoveItem
    , StorageAreaMap_DidSetItem
    , StorageAreaMap_DispatchStorageEvent
    , StorageManagerSet_Clear
    , StorageManagerSet_CloneSessionStorageNamespace
    , StorageManagerSet_DisconnectFromStorageArea
    , StorageManagerSet_RemoveItem
    , StorageManagerSet_SetItem
    , ViewGestureController_DidCollectGeometryForMagnificationGesture
    , ViewGestureController_DidCollectGeometryForSmartMagnificationGesture
    , ViewGestureController_DidHitRenderTreeSizeThreshold
    , ViewGestureGeometryCollector_CollectGeometryForMagnificationGesture
    , ViewGestureGeometryCollector_CollectGeometryForSmartMagnificationGesture
    , ViewGestureGeometryCollector_SetRenderTreeSizeNotificationThreshold
    , VisitedLinkStore_AddVisitedLinkHashFromPage
    , VisitedLinkTableController_AllVisitedLinkStateChanged
    , VisitedLinkTableController_RemoveAllVisitedLinks
    , VisitedLinkTableController_SetVisitedLinkTable
    , VisitedLinkTableController_VisitedLinkStateChanged
    , WebAutomationSessionProxy_ComputeElementLayout
    , WebAutomationSessionProxy_DeleteCookie
    , WebAutomationSessionProxy_EvaluateJavaScriptFunction
    , WebAutomationSessionProxy_GetCookiesForFrame
    , WebAutomationSessionProxy_ResolveChildFrameWithName
    , WebAutomationSessionProxy_ResolveChildFrameWithNodeHandle
    , WebAutomationSessionProxy_ResolveChildFrameWithOrdinal
    , WebAutomationSessionProxy_ResolveParentFrame
    , WebAutomationSessionProxy_SelectOptionElement
    , WebAutomationSessionProxy_SetFilesForInputFileUpload
    , WebAutomationSessionProxy_SnapshotRectForScreenshot
    , WebAutomationSessionProxy_TakeScreenshot
    , WebAutomationSession_DidEvaluateJavaScriptFunction
    , WebAutomationSession_DidTakeScreenshot
    , WebBroadcastChannelRegistry_PostMessageToRemote
    , WebConnection_HandleMessage
    , WebCookieManagerProxy_CookiesDidChange
    , WebCookieManager_DeleteAllCookies
    , WebCookieManager_DeleteAllCookiesModifiedSince
    , WebCookieManager_DeleteCookie
    , WebCookieManager_DeleteCookiesForHostnames
    , WebCookieManager_GetAllCookies
    , WebCookieManager_GetCookies
    , WebCookieManager_GetHTTPCookieAcceptPolicy
    , WebCookieManager_GetHostnamesWithCookies
    , WebCookieManager_SetCookie
    , WebCookieManager_SetCookiePersistentStorage
    , WebCookieManager_SetCookies
    , WebCookieManager_SetHTTPCookieAcceptPolicy
    , WebCookieManager_StartObservingCookieChanges
    , WebCookieManager_StopObservingCookieChanges
    , WebFullScreenManagerProxy_BeganEnterFullScreen
    , WebFullScreenManagerProxy_BeganExitFullScreen
    , WebFullScreenManagerProxy_Close
    , WebFullScreenManagerProxy_EnterFullScreen
    , WebFullScreenManagerProxy_ExitFullScreen
    , WebFullScreenManager_DidEnterFullScreen
    , WebFullScreenManager_DidExitFullScreen
    , WebFullScreenManager_RequestEnterFullScreen
    , WebFullScreenManager_RequestExitFullScreen
    , WebFullScreenManager_RestoreScrollPosition
    , WebFullScreenManager_SaveScrollPosition
    , WebFullScreenManager_SetAnimatingFullScreen
    , WebFullScreenManager_SetFullscreenAutoHideDuration
    , WebFullScreenManager_SetFullscreenControlsHidden
    , WebFullScreenManager_SetFullscreenInsets
    , WebFullScreenManager_WillEnterFullScreen
    , WebFullScreenManager_WillExitFullScreen
    , WebGeolocationManagerProxy_SetEnableHighAccuracy
    , WebGeolocationManagerProxy_StartUpdating
    , WebGeolocationManagerProxy_StopUpdating
    , WebGeolocationManager_DidChangePosition
    , WebGeolocationManager_DidFailToDeterminePosition
    , WebGeolocationManager_ResetPermissions
    , WebIDBConnectionToServer_DidAbortTransaction
    , WebIDBConnectionToServer_DidClearObjectStore
    , WebIDBConnectionToServer_DidCloseFromServer
    , WebIDBConnectionToServer_DidCommitTransaction
    , WebIDBConnectionToServer_DidCreateIndex
    , WebIDBConnectionToServer_DidCreateObjectStore
    , WebIDBConnectionToServer_DidDeleteDatabase
    , WebIDBConnectionToServer_DidDeleteIndex
    , WebIDBConnectionToServer_DidDeleteObjectStore
    , WebIDBConnectionToServer_DidDeleteRecord
    , WebIDBConnectionToServer_DidGetAllDatabaseNamesAndVersions
    , WebIDBConnectionToServer_DidGetAllRecords
    , WebIDBConnectionToServer_DidGetCount
    , WebIDBConnectionToServer_DidGetRecord
    , WebIDBConnectionToServer_DidIterateCursor
    , WebIDBConnectionToServer_DidOpenCursor
    , WebIDBConnectionToServer_DidOpenDatabase
    , WebIDBConnectionToServer_DidPutOrAdd
    , WebIDBConnectionToServer_DidRenameIndex
    , WebIDBConnectionToServer_DidRenameObjectStore
    , WebIDBConnectionToServer_DidStartTransaction
    , WebIDBConnectionToServer_FireVersionChangeEvent
    , WebIDBConnectionToServer_NotifyOpenDBRequestBlocked
    , WebIDBServer_AbortOpenAndUpgradeNeeded
    , WebIDBServer_AbortTransaction
    , WebIDBServer_ClearObjectStore
    , WebIDBServer_CommitTransaction
    , WebIDBServer_CreateIndex
    , WebIDBServer_CreateObjectStore
    , WebIDBServer_DatabaseConnectionClosed
    , WebIDBServer_DatabaseConnectionPendingClose
    , WebIDBServer_DeleteDatabase
    , WebIDBServer_DeleteIndex
    , WebIDBServer_DeleteObjectStore
    , WebIDBServer_DeleteRecord
    , WebIDBServer_DidFinishHandlingVersionChangeTransaction
    , WebIDBServer_DidFireVersionChangeEvent
    , WebIDBServer_EstablishTransaction
    , WebIDBServer_GetAllDatabaseNamesAndVersions
    , WebIDBServer_GetAllRecords
    , WebIDBServer_GetCount
    , WebIDBServer_GetRecord
    , WebIDBServer_IterateCursor
    , WebIDBServer_OpenCursor
    , WebIDBServer_OpenDBRequestCancelled
    , WebIDBServer_OpenDatabase
    , WebIDBServer_PutOrAdd
    , WebIDBServer_RenameIndex
    , WebIDBServer_RenameObjectStore
    , WebInspectorInterruptDispatcher_NotifyNeedDebuggerBreak
    , WebInspectorUIProxy_Append
    , WebInspectorUIProxy_AttachAvailabilityChanged
    , WebInspectorUIProxy_AttachBottom
    , WebInspectorUIProxy_AttachLeft
    , WebInspectorUIProxy_AttachRight
    , WebInspectorUIProxy_BringInspectedPageToFront
    , WebInspectorUIProxy_BringToFront
    , WebInspectorUIProxy_Detach
    , WebInspectorUIProxy_DidClose
    , WebInspectorUIProxy_ElementSelectionChanged
    , WebInspectorUIProxy_FrontendLoaded
    , WebInspectorUIProxy_InspectedURLChanged
    , WebInspectorUIProxy_OpenLocalInspectorFrontend
    , WebInspectorUIProxy_OpenURLExternally
    , WebInspectorUIProxy_Reopen
    , WebInspectorUIProxy_ResetState
    , WebInspectorUIProxy_Save
    , WebInspectorUIProxy_SendMessageToBackend
    , WebInspectorUIProxy_SetAttachedWindowHeight
    , WebInspectorUIProxy_SetAttachedWindowWidth
    , WebInspectorUIProxy_SetDeveloperPreferenceOverride
    , WebInspectorUIProxy_SetForcedAppearance
    , WebInspectorUIProxy_SetFrontendConnection
    , WebInspectorUIProxy_SetSheetRect
    , WebInspectorUIProxy_ShowCertificate
    , WebInspectorUIProxy_StartWindowDrag
    , WebInspectorUIProxy_TimelineRecordingChanged
    , WebInspectorUI_AttachedBottom
    , WebInspectorUI_AttachedLeft
    , WebInspectorUI_AttachedRight
    , WebInspectorUI_Detached
    , WebInspectorUI_DidAppend
    , WebInspectorUI_DidSave
    , WebInspectorUI_EstablishConnection
    , WebInspectorUI_EvaluateInFrontendForTesting
    , WebInspectorUI_SendMessageToFrontend
    , WebInspectorUI_SetDiagnosticLoggingAvailable
    , WebInspectorUI_SetDockingUnavailable
    , WebInspectorUI_SetIsVisible
    , WebInspectorUI_ShowConsole
    , WebInspectorUI_ShowMainResourceForFrame
    , WebInspectorUI_ShowResources
    , WebInspectorUI_StartElementSelection
    , WebInspectorUI_StartPageProfiling
    , WebInspectorUI_StopElementSelection
    , WebInspectorUI_StopPageProfiling
    , WebInspectorUI_UpdateConnection
    , WebInspectorUI_UpdateFindString
    , WebInspector_Close
    , WebInspector_SetAttached
    , WebInspector_SetFrontendConnection
    , WebInspector_Show
    , WebInspector_ShowConsole
    , WebInspector_ShowMainResourceForFrame
    , WebInspector_ShowResources
    , WebInspector_StartElementSelection
    , WebInspector_StartPageProfiling
    , WebInspector_StopElementSelection
    , WebInspector_StopPageProfiling
    , WebMDNSRegister_FinishedRegisteringMDNSName
    , WebNotificationManager_DidClickNotification
    , WebNotificationManager_DidCloseNotifications
    , WebNotificationManager_DidRemoveNotificationDecisions
    , WebNotificationManager_DidShowNotification
    , WebNotificationManager_DidUpdateNotificationDecision
    , WebPageProxy_AbortApplePayAMSUISession
    , WebPageProxy_AddMediaUsageManagerSession
    , WebPageProxy_AddPlaybackTargetPickerClient
    , WebPageProxy_AssistiveTechnologyMakeFirstResponder
    , WebPageProxy_BackForwardAddItem
    , WebPageProxy_BackForwardClear
    , WebPageProxy_BeginMonitoringCaptureDevices
    , WebPageProxy_BindAccessibilityTree
    , WebPageProxy_ChangeUniversalAccessZoomFocus
    , WebPageProxy_ClearAllEditCommands
    , WebPageProxy_ClearTextIndicator
    , WebPageProxy_CloneAttachmentData
    , WebPageProxy_ClosePage
    , WebPageProxy_CommitPotentialTapFailed
    , WebPageProxy_CompositionWasCanceled
    , WebPageProxy_ConfigureLoggingChannel
    , WebPageProxy_ContentFilterDidBlockLoadForFrame
    , WebPageProxy_ContentRuleListNotification
    , WebPageProxy_CouldNotRestorePageState
    , WebPageProxy_CreateInspectorTarget
    , WebPageProxy_CreatePDFHUD
    , WebPageProxy_DecidePolicyForNavigationActionAsync
    , WebPageProxy_DecidePolicyForNewWindowAction
    , WebPageProxy_DecidePolicyForResponse
    , WebPageProxy_DestroyInspectorTarget
    , WebPageProxy_DidCancelClientRedirectForFrame
    , WebPageProxy_DidChangeContentSize
    , WebPageProxy_DidChangeInspectorFrontendCount
    , WebPageProxy_DidChangeIntrinsicContentSize
    , WebPageProxy_DidChangeMainDocument
    , WebPageProxy_DidChangePageCount
    , WebPageProxy_DidChangeProgress
    , WebPageProxy_DidChangeProvisionalURLForFrame
    , WebPageProxy_DidChangeScrollOffsetPinningForMainFrame
    , WebPageProxy_DidChangeScrollbarsForMainFrame
    , WebPageProxy_DidChangeViewportProperties
    , WebPageProxy_DidCommitLoadForFrame
    , WebPageProxy_DidCompleteSyntheticClick
    , WebPageProxy_DidCountStringMatches
    , WebPageProxy_DidCreateContextInWebProcessForVisibilityPropagation
    , WebPageProxy_DidCreateMainFrame
    , WebPageProxy_DidCreateSubframe
    , WebPageProxy_DidCreateWindow
    , WebPageProxy_DidDestroyNavigation
    , WebPageProxy_DidDetectXSSForFrame
    , WebPageProxy_DidDisplayInsecureContentForFrame
    , WebPageProxy_DidEndDragging
    , WebPageProxy_DidExplicitOpenForFrame
    , WebPageProxy_DidFailLoadForFrame
    , WebPageProxy_DidFailProvisionalLoadForFrame
    , WebPageProxy_DidFailToFindString
    , WebPageProxy_DidFailToSuspendAfterProcessSwap
    , WebPageProxy_DidFindString
    , WebPageProxy_DidFindStringMatches
    , WebPageProxy_DidFindTextManipulationItems
    , WebPageProxy_DidFinishDocumentLoadForFrame
    , WebPageProxy_DidFinishLoadForFrame
    , WebPageProxy_DidFinishLoadForQuickLookDocumentInMainFrame
    , WebPageProxy_DidFinishLoadingDataForCustomContentProvider
    , WebPageProxy_DidFinishProgress
    , WebPageProxy_DidFinishServiceWorkerPageRegistration
    , WebPageProxy_DidFirstLayoutForFrame
    , WebPageProxy_DidFirstVisuallyNonEmptyLayoutForFrame
    , WebPageProxy_DidGetImageForFindMatch
    , WebPageProxy_DidGetTapHighlightGeometries
    , WebPageProxy_DidHandleAcceptedCandidate
    , WebPageProxy_DidHandleAdditionalDragItemsRequest
    , WebPageProxy_DidHandleDragStartRequest
    , WebPageProxy_DidInsertAttachmentWithIdentifier
    , WebPageProxy_DidNavigateWithNavigationData
    , WebPageProxy_DidNotHandleTapAsClick
    , WebPageProxy_DidPerformClientRedirect
    , WebPageProxy_DidPerformDictionaryLookup
    , WebPageProxy_DidPerformDragControllerAction
    , WebPageProxy_DidPerformDragOperation
    , WebPageProxy_DidPerformImmediateActionHitTest
    , WebPageProxy_DidPerformServerRedirect
    , WebPageProxy_DidReachLayoutMilestone
    , WebPageProxy_DidReceiveEditDragSnapshot
    , WebPageProxy_DidReceiveEvent
    , WebPageProxy_DidReceivePositionInformation
    , WebPageProxy_DidReceiveServerRedirectForProvisionalLoadForFrame
    , WebPageProxy_DidReceiveTitleForFrame
    , WebPageProxy_DidRemoveAttachmentWithIdentifier
    , WebPageProxy_DidResignInputElementStrongPasswordAppearance
    , WebPageProxy_DidRestoreScrollPosition
    , WebPageProxy_DidRunInsecureContentForFrame
    , WebPageProxy_DidSameDocumentNavigationForFrame
    , WebPageProxy_DidStartLoadForQuickLookDocumentInMainFrame
    , WebPageProxy_DidStartProgress
    , WebPageProxy_DidStartProvisionalLoadForFrame
    , WebPageProxy_DidSuspendAfterProcessSwap
    , WebPageProxy_DidUpdateActivityState
    , WebPageProxy_DidUpdateHistoryTitle
    , WebPageProxy_DidUpdateRenderingAfterCommittingLoad
    , WebPageProxy_DisableDoubleTapGesturesDuringTapIfNecessary
    , WebPageProxy_DisableInspectorNodeSearch
    , WebPageProxy_DismissCorrectionPanel
    , WebPageProxy_EditorStateChanged
    , WebPageProxy_ElementDidBlur
    , WebPageProxy_ElementDidFocus
    , WebPageProxy_EnableInspectorNodeSearch
    , WebPageProxy_EndColorPicker
    , WebPageProxy_EndDataListSuggestions
    , WebPageProxy_EndDateTimePicker
    , WebPageProxy_EnumerateMediaDevicesForFrame
    , WebPageProxy_FixedLayoutSizeDidChange
    , WebPageProxy_FocusedElementDidChangeInputMode
    , WebPageProxy_FocusedFrameChanged
    , WebPageProxy_GetLoadDecisionForIcon
    , WebPageProxy_HandleAcceptsFirstMouse
    , WebPageProxy_HandleAutoFillButtonClick
    , WebPageProxy_HandleAutocorrectionContext
    , WebPageProxy_HandleAutoplayEvent
    , WebPageProxy_HandleClickForDataDetectionResult
    , WebPageProxy_HandleContextMenuTranslation
    , WebPageProxy_HandleKeydownInDataList
    , WebPageProxy_HandleMessage
    , WebPageProxy_HandleMouseDownForModelElement
    , WebPageProxy_HandleMouseMoveForModelElement
    , WebPageProxy_HandleMouseUpForModelElement
    , WebPageProxy_HandleSmartMagnificationInformationForPotentialTap
    , WebPageProxy_HideInspectorHighlight
    , WebPageProxy_HideInspectorIndication
    , WebPageProxy_HidePopupMenu
    , WebPageProxy_HideValidationMessage
    , WebPageProxy_IgnoreWord
    , WebPageProxy_ImageOrMediaDocumentSizeChanged
    , WebPageProxy_IsPlayingMediaDidChange
    , WebPageProxy_LearnWord
    , WebPageProxy_LogDiagnosticMessageFromWebProcess
    , WebPageProxy_LogDiagnosticMessageWithDomainFromWebProcess
    , WebPageProxy_LogDiagnosticMessageWithEnhancedPrivacyFromWebProcess
    , WebPageProxy_LogDiagnosticMessageWithResultFromWebProcess
    , WebPageProxy_LogDiagnosticMessageWithValueDictionaryFromWebProcess
    , WebPageProxy_LogDiagnosticMessageWithValueFromWebProcess
    , WebPageProxy_LogScrollingEvent
    , WebPageProxy_MainFramePluginHandlesPageScaleGestureDidChange
    , WebPageProxy_MakeFirstResponder
    , WebPageProxy_MockMediaPlaybackTargetPickerDismissPopup
    , WebPageProxy_ModelElementAnimationCurrentTime
    , WebPageProxy_ModelElementAnimationDuration
    , WebPageProxy_ModelElementDidCreatePreview
    , WebPageProxy_ModelElementGetCamera
    , WebPageProxy_ModelElementHasAudio
    , WebPageProxy_ModelElementIsLoopingAnimation
    , WebPageProxy_ModelElementIsMuted
    , WebPageProxy_ModelElementIsPlayingAnimation
    , WebPageProxy_ModelElementSetAnimationCurrentTime
    , WebPageProxy_ModelElementSetAnimationIsPlaying
    , WebPageProxy_ModelElementSetCamera
    , WebPageProxy_ModelElementSetIsLoopingAnimation
    , WebPageProxy_ModelElementSetIsMuted
    , WebPageProxy_MouseDidMoveOverElement
    , WebPageProxy_NotifyScrollerThumbIsVisibleInRect
    , WebPageProxy_OpenPDFFromTemporaryFolderWithNativeApplication
    , WebPageProxy_PageDidScroll
    , WebPageProxy_PageExtendedBackgroundColorDidChange
    , WebPageProxy_PageScaleFactorDidChange
    , WebPageProxy_PlaybackTargetPickerClientStateDidChange
    , WebPageProxy_PluginFocusOrWindowFocusChanged
    , WebPageProxy_PluginScaleFactorDidChange
    , WebPageProxy_PluginZoomFactorDidChange
    , WebPageProxy_RecommendedScrollbarStyleDidChange
    , WebPageProxy_RecordAutocorrectionResponse
    , WebPageProxy_RegisterAttachmentIdentifier
    , WebPageProxy_RegisterAttachmentIdentifierFromData
    , WebPageProxy_RegisterAttachmentIdentifierFromFilePath
    , WebPageProxy_RegisterAttachmentsFromSerializedData
    , WebPageProxy_RegisterEditCommandForUndo
    , WebPageProxy_RegisterInsertionUndoGrouping
    , WebPageProxy_RegisterWebProcessAccessibilityToken
    , WebPageProxy_RemoveDictationAlternatives
    , WebPageProxy_RemoveMediaUsageManagerSession
    , WebPageProxy_RemovePDFHUD
    , WebPageProxy_RemovePlaybackTargetPickerClient
    , WebPageProxy_RequestCheckingOfString
    , WebPageProxy_RequestGeolocationPermissionForFrame
    , WebPageProxy_RequestInstallMissingMediaPlugins
    , WebPageProxy_RequestMediaKeySystemPermissionForFrame
    , WebPageProxy_RequestNotificationPermission
    , WebPageProxy_RequestPasswordForQuickLookDocumentInMainFrame
    , WebPageProxy_RequestPointerLock
    , WebPageProxy_RequestPointerUnlock
    , WebPageProxy_RequestScrollToRect
    , WebPageProxy_RequestTextRecognition
    , WebPageProxy_RequestUserMediaPermissionForFrame
    , WebPageProxy_RestorePageCenterAndScale
    , WebPageProxy_RestorePageState
    , WebPageProxy_RevokeGeolocationAuthorizationToken
    , WebPageProxy_RunModal
    , WebPageProxy_RunOpenPanel
    , WebPageProxy_SampledPageTopColorChanged
    , WebPageProxy_SaveImageToLibrary
    , WebPageProxy_SavePDFToFileInDownloadsFolder
    , WebPageProxy_SavePDFToTemporaryFolderAndOpenWithNativeApplication
    , WebPageProxy_SaveRecentSearches
    , WebPageProxy_ScrollingNodeScrollDidEndScroll
    , WebPageProxy_ScrollingNodeScrollWillStartScroll
    , WebPageProxy_SearchTheWeb
    , WebPageProxy_SearchWithSpotlight
    , WebPageProxy_SendMessageToInspectorFrontend
    , WebPageProxy_SendMessageToWebView
    , WebPageProxy_SendMessageToWebViewWithReply
    , WebPageProxy_SetCanShortCircuitHorizontalWheelEvents
    , WebPageProxy_SetColorPickerColor
    , WebPageProxy_SetCursor
    , WebPageProxy_SetCursorHiddenUntilMouseMoves
    , WebPageProxy_SetDataDetectionResult
    , WebPageProxy_SetEditableElementIsFocused
    , WebPageProxy_SetFocus
    , WebPageProxy_SetHasActiveAnimatedScrolls
    , WebPageProxy_SetHasExecutedAppBoundBehaviorBeforeNavigation
    , WebPageProxy_SetHasHadSelectionChangesFromUserInteraction
    , WebPageProxy_SetInputMethodState
    , WebPageProxy_SetIsNeverRichlyEditableForTouchBar
    , WebPageProxy_SetIsResizable
    , WebPageProxy_SetIsTouchBarUpdateSupressedForHiddenContentEditable
    , WebPageProxy_SetIsUsingHighPerformanceWebGL
    , WebPageProxy_SetMenuBarIsVisible
    , WebPageProxy_SetMockMediaPlaybackTargetPickerEnabled
    , WebPageProxy_SetMockMediaPlaybackTargetPickerState
    , WebPageProxy_SetMockVideoPresentationModeEnabled
    , WebPageProxy_SetMockWebAuthenticationConfiguration
    , WebPageProxy_SetNetworkRequestsInProgress
    , WebPageProxy_SetPromisedDataForImage
    , WebPageProxy_SetRenderTreeSize
    , WebPageProxy_SetStatusBarIsVisible
    , WebPageProxy_SetStatusText
    , WebPageProxy_SetTextIndicator
    , WebPageProxy_SetToolbarsAreVisible
    , WebPageProxy_SetWindowFrame
    , WebPageProxy_ShouldAllowDeviceOrientationAndMotionAccess
    , WebPageProxy_ShowColorPicker
    , WebPageProxy_ShowContactPicker
    , WebPageProxy_ShowContextMenu
    , WebPageProxy_ShowCorrectionPanel
    , WebPageProxy_ShowDataDetectorsUIForPositionInformation
    , WebPageProxy_ShowDataListSuggestions
    , WebPageProxy_ShowDateTimePicker
    , WebPageProxy_ShowDictationAlternativeUI
    , WebPageProxy_ShowEmojiPicker
    , WebPageProxy_ShowInspectorHighlight
    , WebPageProxy_ShowInspectorIndication
    , WebPageProxy_ShowMediaControlsContextMenu
    , WebPageProxy_ShowPage
    , WebPageProxy_ShowPlaybackTargetPicker
    , WebPageProxy_ShowPopupMenu
    , WebPageProxy_ShowShareSheet
    , WebPageProxy_ShowTelephoneNumberMenu
    , WebPageProxy_ShowValidationMessage
    , WebPageProxy_Speak
    , WebPageProxy_SpeechSynthesisCancel
    , WebPageProxy_SpeechSynthesisPause
    , WebPageProxy_SpeechSynthesisResume
    , WebPageProxy_SpeechSynthesisSetFinishedCallback
    , WebPageProxy_SpeechSynthesisSpeak
    , WebPageProxy_StartApplePayAMSUISession
    , WebPageProxy_StartDrag
    , WebPageProxy_StartURLSchemeTask
    , WebPageProxy_StopSpeaking
    , WebPageProxy_StopURLSchemeTask
    , WebPageProxy_StoreAppHighlight
    , WebPageProxy_TakeFocus
    , WebPageProxy_TakeModelElementFullscreen
    , WebPageProxy_ThemeColorChanged
    , WebPageProxy_TouchBarMenuDataChanged
    , WebPageProxy_TouchBarMenuItemDataAdded
    , WebPageProxy_TouchBarMenuItemDataRemoved
    , WebPageProxy_UnableToImplementPolicy
    , WebPageProxy_UpdateInputContextAfterBlurringAndRefocusingElement
    , WebPageProxy_UpdateMediaUsageManagerSessionState
    , WebPageProxy_UpdatePDFHUDLocation
    , WebPageProxy_UpdateSpellingUIWithGrammarString
    , WebPageProxy_UpdateSpellingUIWithMisspelledWord
    , WebPageProxy_UpdateStringForFind
    , WebPageProxy_UseFixedLayoutDidChange
    , WebPageProxy_WillGoToBackForwardListItem
    , WebPageProxy_WillPerformClientRedirectForFrame
    , WebPageProxy_WillReceiveEditDragSnapshot
    , WebPageProxy_WillSubmitForm
    , WebPageProxy_WritePromisedAttachmentToPasteboard
    , WebPageProxy_requestPermission
    , WebPageProxy_toggleAutomaticDashSubstitution
    , WebPageProxy_toggleAutomaticLinkDetection
    , WebPageProxy_toggleAutomaticQuoteSubstitution
    , WebPageProxy_toggleAutomaticTextReplacement
    , WebPageProxy_toggleSmartInsertDelete
    , WebPage_AccessibilitySettingsDidChange
    , WebPage_AddConsoleMessage
    , WebPage_AddMIMETypeWithCustomContentProvider
    , WebPage_AdvanceToNextMisspelling
    , WebPage_ApplicationDidBecomeActive
    , WebPage_ApplicationDidEnterBackground
    , WebPage_ApplicationDidEnterBackgroundForMedia
    , WebPage_ApplicationDidFinishSnapshottingAfterEnteringBackground
    , WebPage_ApplicationWillEnterForeground
    , WebPage_ApplicationWillEnterForegroundForMedia
    , WebPage_ApplicationWillResignActive
    , WebPage_ApplyAutocorrection
    , WebPage_AttemptSyntheticClick
    , WebPage_AttributedSubstringForCharacterRangeAsync
    , WebPage_AutofillLoginCredentials
    , WebPage_BeginPrinting
    , WebPage_BeginSelectionInDirection
    , WebPage_BlurFocusedElement
    , WebPage_BoundaryEventOccurred
    , WebPage_CancelAutoscroll
    , WebPage_CancelComposition
    , WebPage_CancelPointer
    , WebPage_CancelPotentialTap
    , WebPage_CapitalizeWord
    , WebPage_CaptureDevicesChanged
    , WebPage_CenterSelectionInVisibleArea
    , WebPage_ChangeFont
    , WebPage_ChangeFontAttributes
    , WebPage_ChangeListType
    , WebPage_ChangeSpellingToWord
    , WebPage_CharacterIndexForPointAsync
    , WebPage_ClearLoadedSubresourceDomains
    , WebPage_ClearSelection
    , WebPage_ClearServiceWorkerEntitlementOverride
    , WebPage_ClearWheelEventTestMonitor
    , WebPage_Close
    , WebPage_CollapseSelectionInFrame
    , WebPage_CommitPotentialTap
    , WebPage_CompleteTextManipulation
    , WebPage_ComputePagesForPrinting
    , WebPage_ConfirmCompositionAsync
    , WebPage_ConnectInspector
    , WebPage_ContentSizeCategoryDidChange
    , WebPage_ContextMenuForKeyEvent
    , WebPage_ContinueWillSubmitForm
    , WebPage_CountStringMatches
    , WebPage_CreateAppHighlightInSelectedRange
    , WebPage_CreateMediaSessionCoordinator
    , WebPage_DataDetectorsDidChangeUI
    , WebPage_DataDetectorsDidHideUI
    , WebPage_DataDetectorsDidPresentUI
    , WebPage_DecreaseListLevel
    , WebPage_DeleteSurrounding
    , WebPage_DetectDataInAllFrames
    , WebPage_DidAcquirePointerLock
    , WebPage_DidCancelCheckingText
    , WebPage_DidCancelForOpenPanel
    , WebPage_DidChangeSelectedIndexForActivePopupMenu
    , WebPage_DidChooseColor
    , WebPage_DidChooseDate
    , WebPage_DidChooseFilesForOpenPanel
    , WebPage_DidChooseFilesForOpenPanelWithDisplayStringAndIcon
    , WebPage_DidCloseSuggestions
    , WebPage_DidConcludeDrop
    , WebPage_DidDismissContextMenu
    , WebPage_DidEndColorPicker
    , WebPage_DidEndDateTimePicker
    , WebPage_DidEndMagnificationGesture
    , WebPage_DidEndRequestInstallMissingMediaPlugins
    , WebPage_DidFinishCheckingText
    , WebPage_DidGetLoadDecisionForIcon
    , WebPage_DidLosePointerLock
    , WebPage_DidNotAcquirePointerLock
    , WebPage_DidReceiveGeolocationPermissionDecision
    , WebPage_DidReceivePolicyDecision
    , WebPage_DidRecognizeLongPress
    , WebPage_DidRemoveBackForwardItem
    , WebPage_DidRemoveEditCommand
    , WebPage_DidSelectDataListOption
    , WebPage_DidSelectItemFromActiveContextMenu
    , WebPage_DidShowContextMenu
    , WebPage_DidStartDrag
    , WebPage_DisconnectInspector
    , WebPage_DispatchWheelEventWithoutScrolling
    , WebPage_DragCancelled
    , WebPage_DragEnded
    , WebPage_DrawPagesForPrinting
    , WebPage_DrawPagesToPDF
    , WebPage_DrawRectToImage
    , WebPage_DrawToPDF
    , WebPage_DrawToPDFiOS
    , WebPage_DynamicViewportSizeUpdate
    , WebPage_EffectiveAppearanceDidChange
    , WebPage_EndPrinting
    , WebPage_EnqueueSecurityPolicyViolationEvent
    , WebPage_ExecuteEditCommand
    , WebPage_ExecuteEditCommandWithCallback
    , WebPage_ExtendSandboxForFilesFromOpenPanel
    , WebPage_ExtendSelection
    , WebPage_FailedToShowPopupMenu
    , WebPage_FindString
    , WebPage_FindStringMatches
    , WebPage_FirstRectForCharacterRangeAsync
    , WebPage_FocusNextFocusedElement
    , WebPage_FocusTextInputContextAndPlaceCaret
    , WebPage_FontAtSelection
    , WebPage_ForceRepaint
    , WebPage_FrameBecameRemote
    , WebPage_FreezeLayerTreeDueToSwipeAnimation
    , WebPage_GamepadActivity
    , WebPage_GenerateSyntheticEditingCommand
    , WebPage_GetAllFrames
    , WebPage_GetApplicationManifest
    , WebPage_GetBytecodeProfile
    , WebPage_GetContentsAsAttributedString
    , WebPage_GetContentsAsMHTMLData
    , WebPage_GetContentsAsString
    , WebPage_GetImageForFindMatch
    , WebPage_GetLoadedSubresourceDomains
    , WebPage_GetMainResourceDataOfFrame
    , WebPage_GetMarkedRangeAsync
    , WebPage_GetPDFFirstPageSize
    , WebPage_GetProcessDisplayName
    , WebPage_GetRectsAtSelectionOffsetWithText
    , WebPage_GetRectsForGranularityWithSelectionOffset
    , WebPage_GetRenderTreeExternalRepresentation
    , WebPage_GetResourceDataFromFrame
    , WebPage_GetSamplingProfilerOutput
    , WebPage_GetSelectedRangeAsync
    , WebPage_GetSelectionAsWebArchiveData
    , WebPage_GetSelectionContext
    , WebPage_GetSelectionOrContentsAsString
    , WebPage_GetSourceForFrame
    , WebPage_GetWebArchiveOfFrame
    , WebPage_GoToBackForwardItem
    , WebPage_HandleAcceptedCandidate
    , WebPage_HandleAlternativeTextUIResult
    , WebPage_HandleDoubleTapForDoubleClickAtPoint
    , WebPage_HandleTwoFingerTapAtPoint
    , WebPage_HardwareKeyboardAvailabilityChanged
    , WebPage_HasMarkedText
    , WebPage_HideFindUI
    , WebPage_ImmediateActionDidCancel
    , WebPage_ImmediateActionDidComplete
    , WebPage_ImmediateActionDidUpdate
    , WebPage_IncreaseListLevel
    , WebPage_IndicateFindMatch
    , WebPage_InsertAttachment
    , WebPage_InsertDictatedTextAsync
    , WebPage_InsertDroppedImagePlaceholders
    , WebPage_InsertTextAsync
    , WebPage_InsertTextPlaceholder
    , WebPage_InspectorNodeSearchEndedAtPosition
    , WebPage_InspectorNodeSearchMovedToPosition
    , WebPage_InvalidateMediaSessionCoordinator
    , WebPage_KeyEvent
    , WebPage_LastNavigationWasAppInitiated
    , WebPage_ListenForLayoutMilestones
    , WebPage_LoadAlternateHTML
    , WebPage_LoadData
    , WebPage_LoadDataInFrame
    , WebPage_LoadRequest
    , WebPage_LoadRequestWaitingForProcessLaunch
    , WebPage_LoadSimulatedRequestAndResponse
    , WebPage_LoadURLInFrame
    , WebPage_LowercaseWord
    , WebPage_MediaKeySystemWasDenied
    , WebPage_MediaKeySystemWasGranted
    , WebPage_MouseEvent
    , WebPage_MoveSelectionAtBoundaryWithDirection
    , WebPage_MoveSelectionByOffset
    , WebPage_NavigateToPDFLinkWithSimulatedClick
    , WebPage_NotifyUserScripts
    , WebPage_OpenPDFWithPreview
    , WebPage_PauseAllMediaPlayback
    , WebPage_PerformActionOnElement
    , WebPage_PerformDictionaryLookupAtLocation
    , WebPage_PerformDictionaryLookupOfCurrentSelection
    , WebPage_PerformDragControllerAction
    , WebPage_PerformImmediateActionHitTestAtLocation
    , WebPage_PlaybackTargetAvailabilityDidChange
    , WebPage_PlaybackTargetPickerWasDismissed
    , WebPage_PlaybackTargetSelected
    , WebPage_PostInjectedBundleMessage
    , WebPage_PotentialTapAtPosition
    , WebPage_PreferencesDidChange
    , WebPage_ReapplyEditCommand
    , WebPage_RegisterUIProcessAccessibilityTokens
    , WebPage_RegisterURLSchemeHandler
    , WebPage_Reload
    , WebPage_RemoveDataDetectedLinks
    , WebPage_RemoveTextPlaceholder
    , WebPage_ReplaceDictatedText
    , WebPage_ReplaceMatches
    , WebPage_ReplaceSelectedText
    , WebPage_ReplaceSelectionWithPasteboardData
    , WebPage_RequestAcceptsFirstMouse
    , WebPage_RequestActiveNowPlayingSessionInfo
    , WebPage_RequestAdditionalItemsForDragSession
    , WebPage_RequestAutocorrectionContext
    , WebPage_RequestAutocorrectionData
    , WebPage_RequestDictationContext
    , WebPage_RequestDocumentEditingContext
    , WebPage_RequestDragStart
    , WebPage_RequestEvasionRectsAboveSelection
    , WebPage_RequestFocusedElementInformation
    , WebPage_RequestFontAttributesAtSelectionStart
    , WebPage_RequestMediaPlaybackState
    , WebPage_RequestPositionInformation
    , WebPage_ResetPotentialTapSecurityOrigin
    , WebPage_RestoreAppHighlightsAndScrollToIndex
    , WebPage_RestoreSelectionInFocusedEditableElement
    , WebPage_RestoreSession
    , WebPage_Resume
    , WebPage_ResumeActiveDOMObjectsAndAnimations
    , WebPage_ResumeAllMediaPlayback
    , WebPage_RunJavaScriptInFrameInScriptWorld
    , WebPage_SavePDF
    , WebPage_ScalePage
    , WebPage_ScalePageInViewCoordinates
    , WebPage_ScaleView
    , WebPage_ScheduleFullEditorStateUpdate
    , WebPage_ScrollBy
    , WebPage_ScrollToRect
    , WebPage_SelectAll
    , WebPage_SelectFindMatch
    , WebPage_SelectPositionAtBoundaryWithDirection
    , WebPage_SelectPositionAtPoint
    , WebPage_SelectTextWithGranularityAtPoint
    , WebPage_SelectWithGesture
    , WebPage_SelectWithTwoTouches
    , WebPage_SelectWordBackward
    , WebPage_SendCOEPCORPViolation
    , WebPage_SendCOEPPolicyInheritenceViolation
    , WebPage_SendCSPViolationReport
    , WebPage_SendComplexTextInputToPlugin
    , WebPage_SendMessageToTargetBackend
    , WebPage_SendMessageToWebExtension
    , WebPage_SendMessageToWebExtensionWithReply
    , WebPage_SendViolationReportWhenNavigatingAwayFromCOOPResponse
    , WebPage_SendViolationReportWhenNavigatingToCOOPResponse
    , WebPage_SetActivityState
    , WebPage_SetAllowsMediaDocumentInlinePlayback
    , WebPage_SetAlwaysShowsHorizontalScroller
    , WebPage_SetAlwaysShowsVerticalScroller
    , WebPage_SetAppHighlightsVisibility
    , WebPage_SetAutoSizingShouldExpandToViewHeight
    , WebPage_SetBackgroundColor
    , WebPage_SetBackgroundExtendsBeyondPage
    , WebPage_SetBaseWritingDirection
    , WebPage_SetCanRunBeforeUnloadConfirmPanel
    , WebPage_SetCanRunModal
    , WebPage_SetCanShowPlaceholder
    , WebPage_SetCanUseCredentialStorage
    , WebPage_SetCompositionAsync
    , WebPage_SetControlledByAutomation
    , WebPage_SetCurrentHistoryItemForReattach
    , WebPage_SetCustomTextEncodingName
    , WebPage_SetDefersLoading
    , WebPage_SetDeviceOrientation
    , WebPage_SetEditable
    , WebPage_SetEnableHorizontalRubberBanding
    , WebPage_SetEnableVerticalRubberBanding
    , WebPage_SetFixedLayoutSize
    , WebPage_SetFocusedElementSelectedIndex
    , WebPage_SetFocusedElementValue
    , WebPage_SetFooterBannerHeightForTesting
    , WebPage_SetForceAlwaysUserScalable
    , WebPage_SetGapBetweenPages
    , WebPage_SetHasResourceLoadClient
    , WebPage_SetHeaderBannerHeightForTesting
    , WebPage_SetIndicating
    , WebPage_SetInitialFocus
    , WebPage_SetIsShowingInputViewForFocusedElement
    , WebPage_SetIsSuspended
    , WebPage_SetIsTakingSnapshotsForApplicationSuspension
    , WebPage_SetLayerHostingMode
    , WebPage_SetMainFrameIsScrollable
    , WebPage_SetMaximumUnobscuredSize
    , WebPage_SetMayStartMediaWhenInWindow
    , WebPage_SetMediaVolume
    , WebPage_SetMinimumSizeForAutoLayout
    , WebPage_SetMinimumUnobscuredSize
    , WebPage_SetMockCameraIsInterrupted
    , WebPage_SetMuted
    , WebPage_SetNeedsDOMWindowResizeEvent
    , WebPage_SetNeedsFontAttributes
    , WebPage_SetOrientationForMediaCapture
    , WebPage_SetOverriddenMediaType
    , WebPage_SetOverrideViewportArguments
    , WebPage_SetPageAndTextZoomFactors
    , WebPage_SetPageLength
    , WebPage_SetPageZoomFactor
    , WebPage_SetPaginationBehavesLikeColumns
    , WebPage_SetPaginationLineGridEnabled
    , WebPage_SetPaginationMode
    , WebPage_SetScreenIsBeingCaptured
    , WebPage_SetScrollPinningBehavior
    , WebPage_SetScrollbarOverlayStyle
    , WebPage_SetShouldDispatchFakeMouseMoveEvents
    , WebPage_SetShouldPlayToPlaybackTarget
    , WebPage_SetShouldRevealCurrentSelectionAfterInsertion
    , WebPage_SetShouldScaleViewToFitDocument
    , WebPage_SetSizeToContentAutoSizeMaximumSize
    , WebPage_SetSmartInsertDeleteEnabled
    , WebPage_SetSuppressScrollbarAnimations
    , WebPage_SetTextAsync
    , WebPage_SetTextForActivePopupMenu
    , WebPage_SetTextZoomFactor
    , WebPage_SetTopContentInset
    , WebPage_SetTopContentInsetFenced
    , WebPage_SetUnderPageBackgroundColorOverride
    , WebPage_SetUnderlayColor
    , WebPage_SetUseFixedLayout
    , WebPage_SetUseIconLoadingClient
    , WebPage_SetUseSystemAppearance
    , WebPage_SetUserAgent
    , WebPage_SetUserInterfaceLayoutDirection
    , WebPage_SetViewportConfigurationViewLayoutSize
    , WebPage_SetViewportSizeForCSSViewportUnits
    , WebPage_SimulateDeviceOrientationChange
    , WebPage_SpeakingErrorOccurred
    , WebPage_StartAutoscrollAtPosition
    , WebPage_StartImageAnalysis
    , WebPage_StartInteractionWithElementContextOrPosition
    , WebPage_StartTextManipulations
    , WebPage_StopInteraction
    , WebPage_StopLoading
    , WebPage_StopLoadingFrame
    , WebPage_StopMediaCapture
    , WebPage_StoreSelectionForAccessibility
    , WebPage_Suspend
    , WebPage_SuspendActiveDOMObjectsAndAnimations
    , WebPage_SuspendAllMediaPlayback
    , WebPage_SystemPreviewActionTriggered
    , WebPage_TakeSnapshot
    , WebPage_TapHighlightAtPosition
    , WebPage_TextInputContextsInRect
    , WebPage_TouchEvent
    , WebPage_TouchWithIdentifierWasRemoved
    , WebPage_TryClose
    , WebPage_TryRestoreScrollPosition
    , WebPage_URLSchemeTaskDidComplete
    , WebPage_URLSchemeTaskDidPerformRedirection
    , WebPage_URLSchemeTaskDidReceiveData
    , WebPage_URLSchemeTaskDidReceiveResponse
    , WebPage_URLSchemeTaskWillPerformRedirection
    , WebPage_UnapplyEditCommand
    , WebPage_UnfreezeLayerTreeDueToSwipeAnimation
    , WebPage_UpdateAttachmentAttributes
    , WebPage_UpdateAttachmentIcon
    , WebPage_UpdateBackForwardListForReattach
    , WebPage_UpdateCORSDisablingPatterns
    , WebPage_UpdateCurrentModifierState
    , WebPage_UpdateSelectionWithDelta
    , WebPage_UpdateSelectionWithExtentPoint
    , WebPage_UpdateSelectionWithExtentPointAndBoundary
    , WebPage_UpdateSelectionWithTouches
    , WebPage_UpdateWebsitePolicies
    , WebPage_UpdateWithTextRecognitionResult
    , WebPage_UppercaseWord
    , WebPage_UserMediaAccessWasDenied
    , WebPage_UserMediaAccessWasGranted
    , WebPage_ValidateCommand
    , WebPage_ViewWillEndLiveResize
    , WebPage_ViewWillStartLiveResize
    , WebPage_VoicesDidChange
    , WebPage_WasLoadedWithDataTransferFromPrevalentResource
    , WebPage_WillStartUserTriggeredZooming
    , WebPage_WindowAndViewFramesChanged
    , WebPage_WindowScreenDidChange
    , WebPage_ZoomPDFIn
    , WebPage_ZoomPDFOut
    , WebPasteboardProxy_ClearClipboard
    , WebPasteboardProxy_UpdateSupportedTypeIdentifiers
    , WebPasteboardProxy_WriteImageToPasteboard
    , WebPasteboardProxy_WriteStringToPasteboard
    , WebPasteboardProxy_WriteToClipboard
    , WebPasteboardProxy_WriteURLToPasteboard
    , WebPasteboardProxy_WriteWebContentToPasteboard
    , WebProcessPool_HandleMessage
    , WebProcessPool_ReportWebContentCPUTime
    , WebProcessPool_StartedUsingGamepads
    , WebProcessPool_StoppedUsingGamepads
    , WebProcessProxy_CacheMediaMIMETypes
    , WebProcessProxy_CreateSpeechRecognitionServer
    , WebProcessProxy_DestroySpeechRecognitionServer
    , WebProcessProxy_DidCollectPrewarmInformation
    , WebProcessProxy_DidCreateSleepDisabler
    , WebProcessProxy_DidDestroyFrame
    , WebProcessProxy_DidDestroySleepDisabler
    , WebProcessProxy_DidDestroyUserGestureToken
    , WebProcessProxy_DidExceedActiveMemoryLimit
    , WebProcessProxy_DidExceedCPULimit
    , WebProcessProxy_DidExceedInactiveMemoryLimit
    , WebProcessProxy_DidExceedInactiveMemoryLimitWhileActive
    , WebProcessProxy_DidReceiveBackgroundResponsivenessPing
    , WebProcessProxy_DisableSuddenTermination
    , WebProcessProxy_EnableSuddenTermination
    , WebProcessProxy_MemoryPressureStatusChanged
    , WebProcessProxy_ReleaseHighPerformanceGPU
    , WebProcessProxy_RequestHighPerformanceGPU
    , WebProcessProxy_SendMessageToWebContext
    , WebProcessProxy_SendMessageToWebContextWithReply
    , WebProcessProxy_SetCaptionDisplayMode
    , WebProcessProxy_SetCaptionLanguage
    , WebProcessProxy_SetDisplayLinkPreferredFramesPerSecond
    , WebProcessProxy_SetIsHoldingLockedFiles
    , WebProcessProxy_StartDisplayLink
    , WebProcessProxy_StopDisplayLink
    , WebProcessProxy_StopResponsivenessTimer
    , WebProcessProxy_SystemBeep
    , WebProcessProxy_UpdateBackForwardItem
    , WebProcess_AccessibilityPreferencesDidChange
    , WebProcess_AddMockMediaDevice
    , WebProcess_BackgroundResponsivenessPing
    , WebProcess_BacklightLevelDidChange
    , WebProcess_ClearCachedPage
    , WebProcess_ClearCurrentModifierStateForTesting
    , WebProcess_ClearMockMediaDevices
    , WebProcess_ClearResourceLoadStatistics
    , WebProcess_ColorPreferencesDidChange
    , WebProcess_ConsumeAudioComponentRegistrations
    , WebProcess_CreateWebPage
    , WebProcess_DeleteWebsiteData
    , WebProcess_DeleteWebsiteDataForOrigins
    , WebProcess_DestroyAutomationSessionProxy
    , WebProcess_DidWriteToPasteboardAsynchronously
    , WebProcess_DisplayConfigurationChanged
    , WebProcess_DisplayWasRefreshed
    , WebProcess_EnableRemoteWebInspector
    , WebProcess_EnsureAutomationSessionProxy
    , WebProcess_EstablishWorkerContextConnectionToNetworkProcess
    , WebProcess_FetchWebsiteData
    , WebProcess_FullKeyboardAccessModeChanged
    , WebProcess_GamepadConnected
    , WebProcess_GamepadDisconnected
    , WebProcess_GarbageCollectJavaScriptObjects
    , WebProcess_GetActivePagesOriginsForTesting
    , WebProcess_GrantAccessToAssetServices
    , WebProcess_GrantUserMediaDeviceSandboxExtensions
    , WebProcess_HandleInjectedBundleMessage
    , WebProcess_InitializeWebProcess
    , WebProcess_IsJITEnabled
    , WebProcess_MarkIsNoLongerPrewarmed
    , WebProcess_NotifyPreferencesChanged
    , WebProcess_PowerSourceDidChange
    , WebProcess_PrepareToSuspend
    , WebProcess_PrewarmWithDomainInformation
    , WebProcess_ProcessDidResume
    , WebProcess_RefreshPlugins
    , WebProcess_RegisterURLSchemeAsBypassingContentSecurityPolicy
    , WebProcess_RegisterURLSchemeAsCORSEnabled
    , WebProcess_RegisterURLSchemeAsCachePartitioned
    , WebProcess_RegisterURLSchemeAsCanDisplayOnlyIfCanRequest
    , WebProcess_RegisterURLSchemeAsDisplayIsolated
    , WebProcess_RegisterURLSchemeAsEmptyDocument
    , WebProcess_RegisterURLSchemeAsLocal
    , WebProcess_RegisterURLSchemeAsNoAccess
    , WebProcess_RegisterURLSchemeAsSecure
    , WebProcess_RemoveMockMediaDevice
    , WebProcess_ResetMockMediaDevices
    , WebProcess_RevokeAccessToAssetServices
    , WebProcess_RevokeUserMediaDeviceSandboxExtensions
    , WebProcess_ScrollerStylePreferenceChanged
    , WebProcess_SeedResourceLoadStatisticsForTesting
    , WebProcess_SendMessageToWebExtension
    , WebProcess_SendResourceLoadStatisticsDataImmediately
    , WebProcess_SetAlwaysUsesComplexTextCodePath
    , WebProcess_SetBackForwardCacheCapacity
    , WebProcess_SetCacheModel
    , WebProcess_SetDefaultRequestTimeoutInterval
    , WebProcess_SetDomainRelaxationForbiddenForURLScheme
    , WebProcess_SetDomainsWithCrossPageStorageAccess
    , WebProcess_SetDomainsWithUserInteraction
    , WebProcess_SetEnabledServices
    , WebProcess_SetEnhancedAccessibility
    , WebProcess_SetHasMouseDevice
    , WebProcess_SetHasStylusDevice
    , WebProcess_SetHasSuspendedPageProxy
    , WebProcess_SetHiddenPageDOMTimerThrottlingIncreaseLimit
    , WebProcess_SetInitialGamepads
    , WebProcess_SetInjectedBundleParameter
    , WebProcess_SetInjectedBundleParameters
    , WebProcess_SetIsInProcessCache
    , WebProcess_SetJavaScriptGarbageCollectorTimerEnabled
    , WebProcess_SetMediaAccessibilityPreferences
    , WebProcess_SetMediaMIMETypes
    , WebProcess_SetMemoryCacheDisabled
    , WebProcess_SetResourceLoadStatisticsEnabled
    , WebProcess_SetScreenProperties
    , WebProcess_SetShouldUseFontSmoothing
    , WebProcess_SetTextCheckerState
    , WebProcess_SetThirdPartyCookieBlockingMode
    , WebProcess_SetUseSystemAppearanceForScrollbars
    , WebProcess_SetWebsiteDataStoreParameters
    , WebProcess_StartMemorySampler
    , WebProcess_StopMemorySampler
    , WebProcess_SwitchFromStaticFontRegistryToUserFontRegistry
    , WebProcess_SystemDidWake
    , WebProcess_SystemWillPowerOn
    , WebProcess_SystemWillSleep
    , WebProcess_UnblockPreferenceService
    , WebProcess_UnblockServicesRequiredByAccessibility
    , WebProcess_UserInterfaceIdiomDidChange
    , WebProcess_UserPreferredLanguagesChanged
    , WebRTCMonitor_NetworksChanged
    , WebRTCResolver_ResolvedAddressError
    , WebRTCResolver_SetResolvedAddress
    , WebResourceLoader_DidBlockAuthenticationChallenge
    , WebResourceLoader_DidFailResourceLoad
    , WebResourceLoader_DidFailServiceWorkerLoad
    , WebResourceLoader_DidFinishResourceLoad
    , WebResourceLoader_DidReceiveData
    , WebResourceLoader_DidReceiveResource
    , WebResourceLoader_DidReceiveResponse
    , WebResourceLoader_DidSendData
    , WebResourceLoader_ServiceWorkerDidNotHandle
    , WebResourceLoader_StopLoadingAfterXFrameOptionsOrContentSecurityPolicyDenied
    , WebResourceLoader_WillSendRequest
    , WebSWClientConnection_DidGetRegistrations
    , WebSWClientConnection_DidMatchRegistration
    , WebSWClientConnection_FireUpdateFoundEvent
    , WebSWClientConnection_JobRejectedInServer
    , WebSWClientConnection_NotifyClientsOfControllerChange
    , WebSWClientConnection_PostMessageToServiceWorkerClient
    , WebSWClientConnection_RegistrationJobResolvedInServer
    , WebSWClientConnection_RegistrationReady
    , WebSWClientConnection_SetDocumentIsControlled
    , WebSWClientConnection_SetRegistrationLastUpdateTime
    , WebSWClientConnection_SetRegistrationUpdateViaCache
    , WebSWClientConnection_SetSWOriginTableIsImported
    , WebSWClientConnection_SetSWOriginTableSharedMemory
    , WebSWClientConnection_StartScriptFetchForServer
    , WebSWClientConnection_UpdateRegistrationState
    , WebSWClientConnection_UpdateWorkerState
    , WebSWContextManagerConnection_CancelFetch
    , WebSWContextManagerConnection_Close
    , WebSWContextManagerConnection_ContinueDidReceiveFetchResponse
    , WebSWContextManagerConnection_DidSaveScriptsToDisk
    , WebSWContextManagerConnection_FindClientByIdentifierCompleted
    , WebSWContextManagerConnection_FireActivateEvent
    , WebSWContextManagerConnection_FireInstallEvent
    , WebSWContextManagerConnection_FirePushEvent
    , WebSWContextManagerConnection_InstallServiceWorker
    , WebSWContextManagerConnection_MatchAllCompleted
    , WebSWContextManagerConnection_PostMessageToServiceWorker
    , WebSWContextManagerConnection_SetThrottleState
    , WebSWContextManagerConnection_SetUserAgent
    , WebSWContextManagerConnection_StartFetch
    , WebSWContextManagerConnection_TerminateWorker
    , WebSWContextManagerConnection_UpdateAppInitiatedValue
    , WebSWContextManagerConnection_UpdatePreferencesStore
    , WebSWServerConnection_AddServiceWorkerRegistrationInServer
    , WebSWServerConnection_DidResolveRegistrationPromise
    , WebSWServerConnection_FinishFetchingScriptInServer
    , WebSWServerConnection_GetPushPermissionState
    , WebSWServerConnection_GetPushSubscription
    , WebSWServerConnection_GetRegistrations
    , WebSWServerConnection_MatchRegistration
    , WebSWServerConnection_PostMessageToServiceWorker
    , WebSWServerConnection_RegisterServiceWorkerClient
    , WebSWServerConnection_RemoveServiceWorkerRegistrationInServer
    , WebSWServerConnection_ScheduleJobInServer
    , WebSWServerConnection_ScheduleUnregisterJobInServer
    , WebSWServerConnection_SetThrottleState
    , WebSWServerConnection_StoreRegistrationsOnDisk
    , WebSWServerConnection_SubscribeToPushService
    , WebSWServerConnection_TerminateWorkerFromClient
    , WebSWServerConnection_UnregisterServiceWorkerClient
    , WebSWServerConnection_UnsubscribeFromPushService
    , WebSWServerConnection_WhenRegistrationReady
    , WebSWServerConnection_WhenServiceWorkerIsTerminatedForTesting
    , WebSWServerToContextConnection_Claim
    , WebSWServerToContextConnection_DidFailHeartBeatCheck
    , WebSWServerToContextConnection_DidFinishActivation
    , WebSWServerToContextConnection_DidFinishInstall
    , WebSWServerToContextConnection_FindClientByIdentifier
    , WebSWServerToContextConnection_MatchAll
    , WebSWServerToContextConnection_PostMessageToServiceWorkerClient
    , WebSWServerToContextConnection_ScriptContextFailedToStart
    , WebSWServerToContextConnection_ScriptContextStarted
    , WebSWServerToContextConnection_SetScriptResource
    , WebSWServerToContextConnection_SetServiceWorkerHasPendingEvents
    , WebSWServerToContextConnection_SkipWaiting
    , WebSWServerToContextConnection_WorkerTerminated
    , WebSocketChannel_DidClose
    , WebSocketChannel_DidConnect
    , WebSocketChannel_DidReceiveBinaryData
    , WebSocketChannel_DidReceiveHandshakeResponse
    , WebSocketChannel_DidReceiveMessageError
    , WebSocketChannel_DidReceiveText
    , WebSocketChannel_DidSendHandshakeRequest
    , WebSocketStream_DidCloseSocketStream
    , WebSocketStream_DidFailSocketStream
    , WebSocketStream_DidFailToReceiveSocketStreamData
    , WebSocketStream_DidOpenSocketStream
    , WebSocketStream_DidReceiveSocketStreamData
    , WebSocketStream_DidSendData
    , WebSocketStream_DidSendHandshake
    , WebSocketStream_DidUpdateBufferedAmount
    , WebSpeechRecognitionConnection_DidReceiveUpdate
    , WebUserContentControllerProxy_DidPostMessage
    , WebUserContentController_AddContentRuleLists
    , WebUserContentController_AddContentWorlds
    , WebUserContentController_AddUserScriptMessageHandlers
    , WebUserContentController_AddUserScripts
    , WebUserContentController_AddUserStyleSheets
    , WebUserContentController_RemoveAllContentRuleLists
    , WebUserContentController_RemoveAllUserScriptMessageHandlers
    , WebUserContentController_RemoveAllUserScriptMessageHandlersForWorlds
    , WebUserContentController_RemoveAllUserScripts
    , WebUserContentController_RemoveAllUserStyleSheets
    , WebUserContentController_RemoveContentRuleList
    , WebUserContentController_RemoveContentWorlds
    , WebUserContentController_RemoveUserScript
    , WebUserContentController_RemoveUserScriptMessageHandler
    , WebUserContentController_RemoveUserStyleSheet
    , InitializeConnection
    , LegacySessionState
    , ProcessOutOfStreamMessage
    , SetStreamDestinationID
    , SyncMessageReply
    , Terminate
    , AuxiliaryProcess_MainThreadPingReply
    , CacheStorageEngineConnection_CachesReply
    , CacheStorageEngineConnection_ClearMemoryRepresentationReply
    , CacheStorageEngineConnection_DeleteMatchingRecordsReply
    , CacheStorageEngineConnection_EngineRepresentationReply
    , CacheStorageEngineConnection_OpenReply
    , CacheStorageEngineConnection_PutRecordsReply
    , CacheStorageEngineConnection_RemoveReply
    , CacheStorageEngineConnection_RetrieveRecordsReply
    , DownloadProxy_DecideDestinationWithSuggestedFilenameReply
    , EventDispatcher_TouchEventReply
    , GPUProcessConnection_BeginRoutingArbitrationWithCategoryReply
    , GPUProcess_CreateGPUConnectionToWebProcessReply
    , GPUProcess_PrepareToSuspendReply
    , GPUProcess_UpdateCaptureAccessReply
    , GPUProcess_WebProcessConnectionCountForTestingReply
    , MediaPlayerPrivateRemote_GetRawCookiesReply
    , MediaPlayerPrivateRemote_RequestResourceReply
    , MediaPlayerPrivateRemote_SendH2PingReply
    , NetworkBroadcastChannelRegistry_PostMessageReply
    , NetworkConnectionToWebProcess_CheckRemotePortForActivityReply
    , NetworkConnectionToWebProcess_ConnectToRTCDataChannelRemoteSourceReply
    , NetworkConnectionToWebProcess_CreateRTCProviderReply
    , NetworkConnectionToWebProcess_EstablishSWContextConnectionReply
    , NetworkConnectionToWebProcess_HasStorageAccessReply
    , NetworkConnectionToWebProcess_IsResourceLoadFinishedReply
    , NetworkConnectionToWebProcess_RequestStorageAccessReply
    , NetworkConnectionToWebProcess_ResourceLoadStatisticsUpdatedReply
    , NetworkConnectionToWebProcess_SendH2PingReply
    , NetworkConnectionToWebProcess_TakeAllMessagesForPortReply
    , NetworkConnectionToWebProcess_WriteBlobsToTemporaryFilesForIndexedDBReply
    , NetworkProcessConnection_CheckProcessLocalPortForActivityReply
    , NetworkProcessConnection_ConnectToRTCDataChannelRemoteSourceReply
    , NetworkProcessProxy_DeleteWebsiteDataInUIProcessForRegistrableDomainsReply
    , NetworkProcessProxy_EstablishWorkerContextConnectionToNetworkProcessReply
    , NetworkProcessProxy_GetAppBoundDomainsReply
    , NetworkProcessProxy_GetWindowSceneIdentifierForPaymentPresentationReply
    , NetworkProcessProxy_RequestStorageAccessConfirmReply
    , NetworkProcessProxy_RequestStorageSpaceReply
    , NetworkProcessProxy_SetDomainsWithCrossPageStorageAccessReply
    , NetworkProcessProxy_TriggerBrowsingContextGroupSwitchForNavigationReply
    , NetworkProcess_AppPrivacyReportTestingDataReply
    , NetworkProcess_CancelDownloadReply
    , NetworkProcess_ClearAppBoundSessionReply
    , NetworkProcess_ClearAppPrivacyReportTestingDataReply
    , NetworkProcess_ClearBundleIdentifierReply
    , NetworkProcess_ClearPrevalentResourceReply
    , NetworkProcess_ClearPrivateClickMeasurementReply
    , NetworkProcess_ClearServiceWorkerEntitlementOverrideReply
    , NetworkProcess_ClearStorageReply
    , NetworkProcess_ClearUserInteractionReply
    , NetworkProcess_CountNonDefaultSessionSetsReply
    , NetworkProcess_CreateNetworkConnectionToWebProcessReply
    , NetworkProcess_DeleteCookiesForTestingReply
    , NetworkProcess_DeletePushAndNotificationRegistrationReply
    , NetworkProcess_DeleteWebsiteDataForOriginsReply
    , NetworkProcess_DeleteWebsiteDataReply
    , NetworkProcess_DomainIDExistsInDatabaseReply
    , NetworkProcess_DumpPrivateClickMeasurementReply
    , NetworkProcess_DumpResourceLoadStatisticsReply
    , NetworkProcess_FetchWebsiteDataReply
    , NetworkProcess_FlushCookiesReply
    , NetworkProcess_GetAllStorageAccessEntriesReply
    , NetworkProcess_GetLocalStorageOriginDetailsReply
    , NetworkProcess_GetOriginsWithPushAndNotificationPermissionsReply
    , NetworkProcess_GetResourceLoadStatisticsDataSummaryReply
    , NetworkProcess_HadUserInteractionReply
    , NetworkProcess_HasAppBoundSessionReply
    , NetworkProcess_HasIsolatedSessionReply
    , NetworkProcess_HasLocalStorageReply
    , NetworkProcess_InsertExpiredStatisticForTestingReply
    , NetworkProcess_IsGrandfatheredReply
    , NetworkProcess_IsPrevalentResourceReply
    , NetworkProcess_IsRegisteredAsRedirectingToReply
    , NetworkProcess_IsRegisteredAsSubFrameUnderReply
    , NetworkProcess_IsRegisteredAsSubresourceUnderReply
    , NetworkProcess_IsRelationshipOnlyInDatabaseOnceReply
    , NetworkProcess_IsResourceLoadStatisticsEphemeralReply
    , NetworkProcess_IsVeryPrevalentResourceReply
    , NetworkProcess_LogUserInteractionReply
    , NetworkProcess_MarkAttributedPrivateClickMeasurementsAsExpiredForTestingReply
    , NetworkProcess_MarkPrivateClickMeasurementsAsExpiredForTestingReply
    , NetworkProcess_MergeStatisticForTestingReply
    , NetworkProcess_PrepareToSuspendReply
    , NetworkProcess_ProcessPushMessageReply
    , NetworkProcess_RenameOriginInWebsiteDataReply
    , NetworkProcess_ResetCacheMaxAgeCapForPrevalentResourcesReply
    , NetworkProcess_ResetCrossSiteLoadsWithLinkDecorationForTestingReply
    , NetworkProcess_ResetParametersToDefaultValuesReply
    , NetworkProcess_ResetQuotaReply
    , NetworkProcess_ScheduleClearInMemoryAndPersistentReply
    , NetworkProcess_ScheduleCookieBlockingUpdateReply
    , NetworkProcess_ScheduleStatisticsAndDataRecordsProcessingReply
    , NetworkProcess_SetAgeCapForClientSideCookiesReply
    , NetworkProcess_SetAppBoundDomainsForResourceLoadStatisticsReply
    , NetworkProcess_SetCacheMaxAgeCapForPrevalentResourcesReply
    , NetworkProcess_SetCrossSiteLoadWithLinkDecorationForTestingReply
    , NetworkProcess_SetFirstPartyHostCNAMEDomainForTestingReply
    , NetworkProcess_SetFirstPartyWebsiteDataRemovalModeForTestingReply
    , NetworkProcess_SetGrandfatheredReply
    , NetworkProcess_SetGrandfatheringTimeReply
    , NetworkProcess_SetIsRunningResourceLoadStatisticsTestReply
    , NetworkProcess_SetLastSeenReply
    , NetworkProcess_SetMaxStatisticsEntriesReply
    , NetworkProcess_SetMinimumTimeBetweenDataRecordsRemovalReply
    , NetworkProcess_SetNotifyPagesWhenDataRecordsWereScannedReply
    , NetworkProcess_SetPCMFraudPreventionValuesForTestingReply
    , NetworkProcess_SetPrevalentResourceForDebugModeReply
    , NetworkProcess_SetPrevalentResourceReply
    , NetworkProcess_SetPrivateClickMeasurementAppBundleIDForTestingReply
    , NetworkProcess_SetPrivateClickMeasurementAttributionReportURLsForTestingReply
    , NetworkProcess_SetPrivateClickMeasurementEphemeralMeasurementForTestingReply
    , NetworkProcess_SetPrivateClickMeasurementOverrideTimerForTestingReply
    , NetworkProcess_SetPrivateClickMeasurementTokenPublicKeyURLForTestingReply
    , NetworkProcess_SetPrivateClickMeasurementTokenSignatureURLForTestingReply
    , NetworkProcess_SetPruneEntriesDownToReply
    , NetworkProcess_SetResourceLoadStatisticsDebugModeReply
    , NetworkProcess_SetShouldClassifyResourcesBeforeDataRecordsRemovalReply
    , NetworkProcess_SetShouldDowngradeReferrerForTestingReply
    , NetworkProcess_SetShouldEnbleSameSiteStrictEnforcementForTestingReply
    , NetworkProcess_SetSubframeUnderTopFrameDomainReply
    , NetworkProcess_SetSubresourceUnderTopFrameDomainReply
    , NetworkProcess_SetSubresourceUniqueRedirectFromReply
    , NetworkProcess_SetSubresourceUniqueRedirectToReply
    , NetworkProcess_SetThirdPartyCNAMEDomainForTestingReply
    , NetworkProcess_SetThirdPartyCookieBlockingModeReply
    , NetworkProcess_SetTimeToLiveUserInteractionReply
    , NetworkProcess_SetToSameSiteStrictCookiesForTestingReply
    , NetworkProcess_SetTopFrameUniqueRedirectFromReply
    , NetworkProcess_SetTopFrameUniqueRedirectToReply
    , NetworkProcess_SetVeryPrevalentResourceReply
    , NetworkProcess_SimulateResourceLoadStatisticsSessionRestartReply
    , NetworkProcess_StatisticsDatabaseHasAllTablesReply
    , NetworkProcess_SyncLocalStorageReply
    , NetworkProcess_UpdateBundleIdentifierReply
    , NetworkProcess_UpdatePrevalentDomainsToBlockCookiesForReply
    , NetworkSocketChannel_SendDataReply
    , NetworkSocketChannel_SendStringReply
    , NetworkStorageManager_CloseAccessHandleReply
    , NetworkStorageManager_CreateSyncAccessHandleReply
    , NetworkStorageManager_FileSystemGetDirectoryReply
    , NetworkStorageManager_GetDirectoryHandleReply
    , NetworkStorageManager_GetFileHandleReply
    , NetworkStorageManager_GetFileReply
    , NetworkStorageManager_GetHandleNamesReply
    , NetworkStorageManager_GetHandleReply
    , NetworkStorageManager_IsSameEntryReply
    , NetworkStorageManager_MoveReply
    , NetworkStorageManager_PersistReply
    , NetworkStorageManager_PersistedReply
    , NetworkStorageManager_RemoveEntryReply
    , NetworkStorageManager_ResolveReply
    , NotificationManagerMessageHandler_RequestSystemNotificationPermissionReply
    , PlatformXRSystem_EnumerateImmersiveXRDevicesReply
    , PlatformXRSystem_RequestFrameReply
    , RemoteAudioDestinationManager_DeleteAudioDestinationReply
    , RemoteAudioDestinationManager_StartAudioDestinationReply
    , RemoteAudioDestinationManager_StopAudioDestinationReply
    , RemoteAudioMediaStreamTrackRendererInternalUnitManager_CreateUnitReply
    , RemoteCDMInstanceProxy_InitializeWithConfigurationReply
    , RemoteCDMInstanceProxy_SetServerCertificateReply
    , RemoteCDMInstanceSessionProxy_CloseSessionReply
    , RemoteCDMInstanceSessionProxy_LoadSessionReply
    , RemoteCDMInstanceSessionProxy_RemoveSessionDataReply
    , RemoteCDMInstanceSessionProxy_RequestLicenseReply
    , RemoteCDMInstanceSessionProxy_UpdateLicenseReply
    , RemoteCDMProxy_GetSupportedConfigurationReply
    , RemoteMediaEngineConfigurationFactoryProxy_CreateDecodingConfigurationReply
    , RemoteMediaEngineConfigurationFactoryProxy_CreateEncodingConfigurationReply
    , RemoteMediaPlayerProxy_DidLoadingProgressReply
    , RemoteMediaPlayerProxy_LoadMediaSourceReply
    , RemoteMediaPlayerProxy_LoadReply
    , RemoteMediaPlayerProxy_PerformTaskAtMediaTimeReply
    , RemoteMediaPlayerProxy_PrepareForPlaybackReply
    , RemoteMediaRecorderManager_CreateRecorderReply
    , RemoteMediaRecorder_FetchDataReply
    , RemoteMediaRecorder_PauseReply
    , RemoteMediaRecorder_ResumeReply
    , RemoteMediaRecorder_StopRecordingReply
    , RemoteMediaResourceManager_RedirectReceivedReply
    , RemoteMediaResourceManager_ResponseReceivedReply
    , RemoteMediaSessionCoordinatorProxy_CoordinatePauseReply
    , RemoteMediaSessionCoordinatorProxy_CoordinatePlayReply
    , RemoteMediaSessionCoordinatorProxy_CoordinateSeekToReply
    , RemoteMediaSessionCoordinatorProxy_CoordinateSetTrackReply
    , RemoteMediaSessionCoordinatorProxy_JoinReply
    , RemoteMediaSessionCoordinator_PauseSessionReply
    , RemoteMediaSessionCoordinator_PlaySessionReply
    , RemoteMediaSessionCoordinator_SeekSessionToTimeReply
    , RemoteMediaSessionCoordinator_SetSessionTrackReply
    , RemoteSampleBufferDisplayLayerManager_CreateLayerReply
    , RemoteSourceBufferProxy_BufferedSamplesForTrackIdReply
    , RemoteSourceBufferProxy_EnqueuedSamplesForTrackIDReply
    , RemoteSourceBufferProxy_RemoveCodedFramesReply
    , SourceBufferPrivateRemote_SourceBufferPrivateDidReceiveInitializationSegmentReply
    , WebAutomationSessionProxy_ComputeElementLayoutReply
    , WebAutomationSessionProxy_DeleteCookieReply
    , WebAutomationSessionProxy_GetCookiesForFrameReply
    , WebAutomationSessionProxy_ResolveChildFrameWithNameReply
    , WebAutomationSessionProxy_ResolveChildFrameWithNodeHandleReply
    , WebAutomationSessionProxy_ResolveChildFrameWithOrdinalReply
    , WebAutomationSessionProxy_ResolveParentFrameReply
    , WebAutomationSessionProxy_SelectOptionElementReply
    , WebAutomationSessionProxy_SetFilesForInputFileUploadReply
    , WebAutomationSessionProxy_SnapshotRectForScreenshotReply
    , WebBroadcastChannelRegistry_PostMessageToRemoteReply
    , WebCookieManager_DeleteAllCookiesModifiedSinceReply
    , WebCookieManager_DeleteCookieReply
    , WebCookieManager_GetAllCookiesReply
    , WebCookieManager_GetCookiesReply
    , WebCookieManager_GetHTTPCookieAcceptPolicyReply
    , WebCookieManager_GetHostnamesWithCookiesReply
    , WebCookieManager_SetCookieReply
    , WebCookieManager_SetCookiesReply
    , WebCookieManager_SetHTTPCookieAcceptPolicyReply
    , WebPageProxy_BindAccessibilityTreeReply
    , WebPageProxy_EnumerateMediaDevicesForFrameReply
    , WebPageProxy_ModelElementAnimationCurrentTimeReply
    , WebPageProxy_ModelElementAnimationDurationReply
    , WebPageProxy_ModelElementDidCreatePreviewReply
    , WebPageProxy_ModelElementGetCameraReply
    , WebPageProxy_ModelElementHasAudioReply
    , WebPageProxy_ModelElementIsLoopingAnimationReply
    , WebPageProxy_ModelElementIsMutedReply
    , WebPageProxy_ModelElementIsPlayingAnimationReply
    , WebPageProxy_ModelElementSetAnimationCurrentTimeReply
    , WebPageProxy_ModelElementSetAnimationIsPlayingReply
    , WebPageProxy_ModelElementSetCameraReply
    , WebPageProxy_ModelElementSetIsLoopingAnimationReply
    , WebPageProxy_ModelElementSetIsMutedReply
    , WebPageProxy_RequestNotificationPermissionReply
    , WebPageProxy_RequestPasswordForQuickLookDocumentInMainFrameReply
    , WebPageProxy_RequestTextRecognitionReply
    , WebPageProxy_SendMessageToWebViewWithReplyReply
    , WebPageProxy_ShouldAllowDeviceOrientationAndMotionAccessReply
    , WebPageProxy_ShowContactPickerReply
    , WebPageProxy_ShowEmojiPickerReply
    , WebPageProxy_ShowMediaControlsContextMenuReply
    , WebPageProxy_ShowShareSheetReply
    , WebPageProxy_SpeechSynthesisPauseReply
    , WebPageProxy_SpeechSynthesisResumeReply
    , WebPageProxy_SpeechSynthesisSetFinishedCallbackReply
    , WebPageProxy_SpeechSynthesisSpeakReply
    , WebPageProxy_StartApplePayAMSUISessionReply
    , WebPageProxy_requestPermissionReply
    , WebPage_ApplyAutocorrectionReply
    , WebPage_AttributedSubstringForCharacterRangeAsyncReply
    , WebPage_BeginSelectionInDirectionReply
    , WebPage_CharacterIndexForPointAsyncReply
    , WebPage_ClearServiceWorkerEntitlementOverrideReply
    , WebPage_CompleteTextManipulationReply
    , WebPage_ComputePagesForPrintingReply
    , WebPage_CreateMediaSessionCoordinatorReply
    , WebPage_DetectDataInAllFramesReply
    , WebPage_DidGetLoadDecisionForIconReply
    , WebPage_DispatchWheelEventWithoutScrollingReply
    , WebPage_DrawPagesForPrintingReply
    , WebPage_DrawPagesToPDFReply
    , WebPage_DrawRectToImageReply
    , WebPage_DrawToPDFReply
    , WebPage_DrawToPDFiOSReply
    , WebPage_ExecuteEditCommandWithCallbackReply
    , WebPage_ExtendSelectionReply
    , WebPage_FindStringReply
    , WebPage_FirstRectForCharacterRangeAsyncReply
    , WebPage_FocusNextFocusedElementReply
    , WebPage_FocusTextInputContextAndPlaceCaretReply
    , WebPage_FontAtSelectionReply
    , WebPage_ForceRepaintReply
    , WebPage_GetAllFramesReply
    , WebPage_GetApplicationManifestReply
    , WebPage_GetBytecodeProfileReply
    , WebPage_GetContentsAsAttributedStringReply
    , WebPage_GetContentsAsMHTMLDataReply
    , WebPage_GetContentsAsStringReply
    , WebPage_GetLoadedSubresourceDomainsReply
    , WebPage_GetMainResourceDataOfFrameReply
    , WebPage_GetMarkedRangeAsyncReply
    , WebPage_GetPDFFirstPageSizeReply
    , WebPage_GetProcessDisplayNameReply
    , WebPage_GetRectsAtSelectionOffsetWithTextReply
    , WebPage_GetRectsForGranularityWithSelectionOffsetReply
    , WebPage_GetRenderTreeExternalRepresentationReply
    , WebPage_GetResourceDataFromFrameReply
    , WebPage_GetSamplingProfilerOutputReply
    , WebPage_GetSelectedRangeAsyncReply
    , WebPage_GetSelectionAsWebArchiveDataReply
    , WebPage_GetSelectionContextReply
    , WebPage_GetSelectionOrContentsAsStringReply
    , WebPage_GetSourceForFrameReply
    , WebPage_GetWebArchiveOfFrameReply
    , WebPage_HasMarkedTextReply
    , WebPage_InsertAttachmentReply
    , WebPage_InsertDroppedImagePlaceholdersReply
    , WebPage_InsertTextPlaceholderReply
    , WebPage_LastNavigationWasAppInitiatedReply
    , WebPage_MediaKeySystemWasGrantedReply
    , WebPage_MoveSelectionAtBoundaryWithDirectionReply
    , WebPage_MoveSelectionByOffsetReply
    , WebPage_OpenPDFWithPreviewReply
    , WebPage_PauseAllMediaPlaybackReply
    , WebPage_RemoveDataDetectedLinksReply
    , WebPage_RemoveTextPlaceholderReply
    , WebPage_ReplaceMatchesReply
    , WebPage_RequestActiveNowPlayingSessionInfoReply
    , WebPage_RequestAutocorrectionDataReply
    , WebPage_RequestDictationContextReply
    , WebPage_RequestDocumentEditingContextReply
    , WebPage_RequestEvasionRectsAboveSelectionReply
    , WebPage_RequestFocusedElementInformationReply
    , WebPage_RequestFontAttributesAtSelectionStartReply
    , WebPage_RequestMediaPlaybackStateReply
    , WebPage_ResumeAllMediaPlaybackReply
    , WebPage_ResumeReply
    , WebPage_RunJavaScriptInFrameInScriptWorldReply
    , WebPage_SavePDFReply
    , WebPage_SelectPositionAtBoundaryWithDirectionReply
    , WebPage_SelectPositionAtPointReply
    , WebPage_SelectTextWithGranularityAtPointReply
    , WebPage_SelectWithGestureReply
    , WebPage_SelectWithTwoTouchesReply
    , WebPage_SendMessageToWebExtensionWithReplyReply
    , WebPage_SetActivityStateReply
    , WebPage_SetInitialFocusReply
    , WebPage_SetMutedReply
    , WebPage_StartTextManipulationsReply
    , WebPage_StopMediaCaptureReply
    , WebPage_SuspendAllMediaPlaybackReply
    , WebPage_SuspendReply
    , WebPage_TakeSnapshotReply
    , WebPage_TextInputContextsInRectReply
    , WebPage_TryCloseReply
    , WebPage_URLSchemeTaskWillPerformRedirectionReply
    , WebPage_UpdateAttachmentAttributesReply
    , WebPage_UpdateSelectionWithDeltaReply
    , WebPage_UpdateSelectionWithExtentPointAndBoundaryReply
    , WebPage_UpdateSelectionWithExtentPointReply
    , WebPage_UpdateSelectionWithTouchesReply
    , WebPage_UpdateWithTextRecognitionResultReply
    , WebPage_UserMediaAccessWasGrantedReply
    , WebPage_ValidateCommandReply
    , WebProcessProxy_SendMessageToWebContextWithReplyReply
    , WebProcess_ClearCachedPageReply
    , WebProcess_DeleteWebsiteDataForOriginsReply
    , WebProcess_DeleteWebsiteDataReply
    , WebProcess_EstablishWorkerContextConnectionToNetworkProcessReply
    , WebProcess_FetchWebsiteDataReply
    , WebProcess_GetActivePagesOriginsForTestingReply
    , WebProcess_IsJITEnabledReply
    , WebProcess_PrepareToSuspendReply
    , WebProcess_SeedResourceLoadStatisticsForTestingReply
    , WebProcess_SendResourceLoadStatisticsDataImmediatelyReply
    , WebProcess_SetDomainsWithCrossPageStorageAccessReply
    , WebProcess_SetThirdPartyCookieBlockingModeReply
    , WebSWClientConnection_SetDocumentIsControlledReply
    , WebSWContextManagerConnection_FirePushEventReply
    , WebSWServerConnection_GetPushPermissionStateReply
    , WebSWServerConnection_GetPushSubscriptionReply
    , WebSWServerConnection_ScheduleUnregisterJobInServerReply
    , WebSWServerConnection_StoreRegistrationsOnDiskReply
    , WebSWServerConnection_SubscribeToPushServiceReply
    , WebSWServerConnection_TerminateWorkerFromClientReply
    , WebSWServerConnection_UnsubscribeFromPushServiceReply
    , WebSWServerConnection_WhenServiceWorkerIsTerminatedForTestingReply
    , WebSWServerToContextConnection_ClaimReply
    , WebSWServerToContextConnection_SkipWaitingReply
    , WebUserContentControllerProxy_DidPostMessageReply
    , GPUConnectionToWebProcess_EnsureAudioSession
    , NetworkConnectionToWebProcess_BlobSize
    , NetworkConnectionToWebProcess_CookieRequestHeaderFieldValue
    , NetworkConnectionToWebProcess_CookiesForDOM
    , NetworkConnectionToWebProcess_DomCookiesForHost
    , NetworkConnectionToWebProcess_GetNetworkLoadInformationResponse
    , NetworkConnectionToWebProcess_GetNetworkLoadIntermediateInformation
    , NetworkConnectionToWebProcess_GetRawCookies
    , NetworkConnectionToWebProcess_PerformSynchronousLoad
    , NetworkConnectionToWebProcess_TakeNetworkLoadInformationMetrics
    , NetworkConnectionToWebProcess_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply
    , NetworkProcessProxy_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply
    , NetworkProcess_ProcessWillSuspendImminentlyForTestingSync
    , NetworkProcess_ResetServiceWorkerFetchTimeoutForTesting
    , NetworkProcess_SetAllowsAnySSLCertificateForWebSocket
    , NetworkProcess_SetCacheModelSynchronouslyForTesting
    , NetworkProcess_SetServiceWorkerFetchTimeoutForTesting
    , RemoteAdapter_RequestDevice
    , RemoteAudioDestinationManager_CreateAudioDestination
    , RemoteAudioSessionProxy_TryToSetActive
    , RemoteBuffer_MapAsync
    , RemoteCDMFactoryProxy_CreateCDM
    , RemoteCDMFactoryProxy_SupportsKeySystem
    , RemoteCDMInstanceProxy_CreateSession
    , RemoteCDMProxy_CreateInstance
    , RemoteDevice_CreateComputePipelineAsync
    , RemoteDevice_CreateRenderPipelineAsync
    , RemoteDevice_PopErrorScope
    , RemoteGPU_RequestAdapter
    , RemoteGraphicsContextGL_CheckFramebufferStatus
    , RemoteGraphicsContextGL_ClientWaitSync
    , RemoteGraphicsContextGL_CopyTextureFromMedia
    , RemoteGraphicsContextGL_CreateBuffer
    , RemoteGraphicsContextGL_CreateFramebuffer
    , RemoteGraphicsContextGL_CreateProgram
    , RemoteGraphicsContextGL_CreateQuery
    , RemoteGraphicsContextGL_CreateRenderbuffer
    , RemoteGraphicsContextGL_CreateSampler
    , RemoteGraphicsContextGL_CreateShader
    , RemoteGraphicsContextGL_CreateTexture
    , RemoteGraphicsContextGL_CreateTransformFeedback
    , RemoteGraphicsContextGL_CreateVertexArray
    , RemoteGraphicsContextGL_FenceSync
    , RemoteGraphicsContextGL_GetActiveAttrib
    , RemoteGraphicsContextGL_GetActiveUniform
    , RemoteGraphicsContextGL_GetActiveUniformBlockName
    , RemoteGraphicsContextGL_GetActiveUniformBlockiv
    , RemoteGraphicsContextGL_GetActiveUniforms
    , RemoteGraphicsContextGL_GetAttribLocation
    , RemoteGraphicsContextGL_GetBooleanv
    , RemoteGraphicsContextGL_GetBufferParameteri
    , RemoteGraphicsContextGL_GetBufferSubData
    , RemoteGraphicsContextGL_GetError
    , RemoteGraphicsContextGL_GetFloatv
    , RemoteGraphicsContextGL_GetFragDataLocation
    , RemoteGraphicsContextGL_GetFramebufferAttachmentParameteri
    , RemoteGraphicsContextGL_GetGraphicsResetStatusARB
    , RemoteGraphicsContextGL_GetInteger64
    , RemoteGraphicsContextGL_GetInteger64i
    , RemoteGraphicsContextGL_GetIntegerv
    , RemoteGraphicsContextGL_GetInternalformativ
    , RemoteGraphicsContextGL_GetProgramInfoLog
    , RemoteGraphicsContextGL_GetProgrami
    , RemoteGraphicsContextGL_GetQuery
    , RemoteGraphicsContextGL_GetQueryObjectui
    , RemoteGraphicsContextGL_GetRenderbufferParameteri
    , RemoteGraphicsContextGL_GetSamplerParameterf
    , RemoteGraphicsContextGL_GetSamplerParameteri
    , RemoteGraphicsContextGL_GetShaderInfoLog
    , RemoteGraphicsContextGL_GetShaderPrecisionFormat
    , RemoteGraphicsContextGL_GetShaderSource
    , RemoteGraphicsContextGL_GetShaderi
    , RemoteGraphicsContextGL_GetString
    , RemoteGraphicsContextGL_GetSynci
    , RemoteGraphicsContextGL_GetTexParameterf
    , RemoteGraphicsContextGL_GetTexParameteri
    , RemoteGraphicsContextGL_GetTransformFeedbackVarying
    , RemoteGraphicsContextGL_GetTranslatedShaderSourceANGLE
    , RemoteGraphicsContextGL_GetUniformBlockIndex
    , RemoteGraphicsContextGL_GetUniformIndices
    , RemoteGraphicsContextGL_GetUniformLocation
    , RemoteGraphicsContextGL_GetUniformfv
    , RemoteGraphicsContextGL_GetUniformiv
    , RemoteGraphicsContextGL_GetUniformuiv
    , RemoteGraphicsContextGL_GetVertexAttribOffset
    , RemoteGraphicsContextGL_IsBuffer
    , RemoteGraphicsContextGL_IsEnabled
    , RemoteGraphicsContextGL_IsFramebuffer
    , RemoteGraphicsContextGL_IsProgram
    , RemoteGraphicsContextGL_IsQuery
    , RemoteGraphicsContextGL_IsRenderbuffer
    , RemoteGraphicsContextGL_IsSampler
    , RemoteGraphicsContextGL_IsShader
    , RemoteGraphicsContextGL_IsSync
    , RemoteGraphicsContextGL_IsTexture
    , RemoteGraphicsContextGL_IsTransformFeedback
    , RemoteGraphicsContextGL_IsVertexArray
    , RemoteGraphicsContextGL_MoveErrorsToSyntheticErrorList
    , RemoteGraphicsContextGL_PaintCompositedResultsToCanvas
    , RemoteGraphicsContextGL_PaintRenderingResultsToCanvas
    , RemoteGraphicsContextGL_PaintRenderingResultsToPixelBuffer
    , RemoteGraphicsContextGL_PrepareForDisplay
    , RemoteGraphicsContextGL_ReadnPixels0
    , RemoteLegacyCDMFactoryProxy_CreateCDM
    , RemoteLegacyCDMFactoryProxy_SupportsKeySystem
    , RemoteLegacyCDMProxy_CreateSession
    , RemoteLegacyCDMProxy_SupportsMIMEType
    , RemoteLegacyCDMSessionProxy_CachedKeyForKeyID
    , RemoteLegacyCDMSessionProxy_GenerateKeyRequest
    , RemoteLegacyCDMSessionProxy_Update
    , RemoteMediaPlayerManagerProxy_GetSupportedTypes
    , RemoteMediaPlayerManagerProxy_OriginsInMediaCache
    , RemoteMediaPlayerManagerProxy_SupportsKeySystem
    , RemoteMediaPlayerManagerProxy_SupportsTypeAndCodecs
    , RemoteMediaPlayerProxy_AccessLog
    , RemoteMediaPlayerProxy_ColorSpace
    , RemoteMediaPlayerProxy_ErrorLog
    , RemoteMediaPlayerProxy_NativeImageForCurrentTime
    , RemoteMediaPlayerProxy_PixelBufferForCurrentTimeIfChanged
    , RemoteMediaPlayerProxy_WouldTaintOrigin
    , RemoteMediaSourceProxy_AddSourceBuffer
    , RemoteQueue_OnSubmittedWorkDone
    , RemoteRenderingBackend_GetDataForImageBuffer
    , RemoteRenderingBackend_GetDataURLForImageBuffer
    , RemoteRenderingBackend_GetShareableBitmapForImageBuffer
    , RemoteRenderingBackend_SemaphoreForGetPixelBuffer
    , RemoteRenderingBackend_UpdateSharedMemoryAndSemaphoreForGetPixelBuffer
    , RemoteRenderingBackend_UpdateSharedMemoryForGetPixelBuffer
    , RemoteShaderModule_CompilationInfo
    , RemoteSourceBufferProxy_CanSwitchToType
    , RemoteSourceBufferProxy_EvictCodedFrames
    , RemoteSourceBufferProxy_UpdateBufferedFromTrackBuffers
    , StorageManagerSet_ConnectToLocalStorageArea
    , StorageManagerSet_ConnectToSessionStorageArea
    , StorageManagerSet_ConnectToTransientLocalStorageArea
    , StorageManagerSet_GetValues
    , WebFullScreenManagerProxy_SupportsFullScreen
    , WebPageProxy_AccessibilityScreenToRootView
    , WebPageProxy_BackForwardGoToItem
    , WebPageProxy_BackForwardItemAtIndex
    , WebPageProxy_BackForwardListCounts
    , WebPageProxy_CanUndoRedo
    , WebPageProxy_CheckGrammarOfString
    , WebPageProxy_CheckSpellingOfString
    , WebPageProxy_CheckTextOfParagraph
    , WebPageProxy_CreateNewPage
    , WebPageProxy_DecidePolicyForNavigationActionSync
    , WebPageProxy_DictationAlternatives
    , WebPageProxy_DismissCorrectionPanelSoon
    , WebPageProxy_ExceededDatabaseQuota
    , WebPageProxy_ExecuteSavedCommandBySelector
    , WebPageProxy_ExecuteUndoRedo
    , WebPageProxy_GetGuessesForWord
    , WebPageProxy_GetIsSpeaking
    , WebPageProxy_GetMenuBarIsVisible
    , WebPageProxy_GetStatusBarIsVisible
    , WebPageProxy_GetToolbarsAreVisible
    , WebPageProxy_GetWindowFrame
    , WebPageProxy_HandleSynchronousMessage
    , WebPageProxy_InterpretKeyEvent
    , WebPageProxy_LoadRecentSearches
    , WebPageProxy_LoadSynchronousURLSchemeTask
    , WebPageProxy_PrintFrame
    , WebPageProxy_ReachedApplicationCacheOriginQuota
    , WebPageProxy_RequestDOMPasteAccess
    , WebPageProxy_ResolveWebGLPolicyForURL
    , WebPageProxy_RootViewToAccessibilityScreen
    , WebPageProxy_RootViewToScreen
    , WebPageProxy_RunBeforeUnloadConfirmPanel
    , WebPageProxy_RunJavaScriptAlert
    , WebPageProxy_RunJavaScriptConfirm
    , WebPageProxy_RunJavaScriptPrompt
    , WebPageProxy_ScreenToRootView
    , WebPageProxy_SerializedAttachmentDataForIdentifiers
    , WebPageProxy_ShowPDFContextMenu
    , WebPageProxy_SignedPublicKeyAndChallengeString
    , WebPageProxy_SpeechSynthesisVoiceList
    , WebPageProxy_SpellingUIIsShowing
    , WebPageProxy_SubstitutionsPanelIsShowing
    , WebPageProxy_UnwrapCryptoKey
    , WebPageProxy_WebGLPolicyForURL
    , WebPageProxy_WrapCryptoKey
    , WebPage_ComputePagesForPrintingiOS
    , WebPage_GetDataSelectionForPasteboard
    , WebPage_GetPositionInformation
    , WebPage_GetStringSelectionForPasteboard
    , WebPage_ReadSelectionFromPasteboard
    , WebPage_ShouldDelayWindowOrderingEvent
    , WebPage_SyncApplyAutocorrection
    , WebPage_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply
    , WebPage_TouchEventSync
    , WebPasteboardProxy_AddPasteboardTypes
    , WebPasteboardProxy_AllPasteboardItemInfo
    , WebPasteboardProxy_ContainsStringSafeForDOMToReadForType
    , WebPasteboardProxy_ContainsURLStringSuitableForLoading
    , WebPasteboardProxy_GetNumberOfFiles
    , WebPasteboardProxy_GetPasteboardBufferForType
    , WebPasteboardProxy_GetPasteboardChangeCount
    , WebPasteboardProxy_GetPasteboardColor
    , WebPasteboardProxy_GetPasteboardItemsCount
    , WebPasteboardProxy_GetPasteboardPathnamesForType
    , WebPasteboardProxy_GetPasteboardStringForType
    , WebPasteboardProxy_GetPasteboardStringsForType
    , WebPasteboardProxy_GetPasteboardTypes
    , WebPasteboardProxy_GetPasteboardURL
    , WebPasteboardProxy_GetTypes
    , WebPasteboardProxy_InformationForItemAtIndex
    , WebPasteboardProxy_ReadBuffer
    , WebPasteboardProxy_ReadBufferFromPasteboard
    , WebPasteboardProxy_ReadFilePaths
    , WebPasteboardProxy_ReadStringFromPasteboard
    , WebPasteboardProxy_ReadText
    , WebPasteboardProxy_ReadURLFromPasteboard
    , WebPasteboardProxy_SetPasteboardBufferForType
    , WebPasteboardProxy_SetPasteboardColor
    , WebPasteboardProxy_SetPasteboardStringForType
    , WebPasteboardProxy_SetPasteboardTypes
    , WebPasteboardProxy_SetPasteboardURL
    , WebPasteboardProxy_TypesSafeForDOMToReadAndWrite
    , WebPasteboardProxy_URLStringSuitableForLoading
    , WebPasteboardProxy_WriteCustomData
    , WebProcessPool_HandleSynchronousMessage
    , WebProcessProxy_GetGPUProcessConnection
    , WebProcessProxy_GetNetworkProcessConnection
    , WebProcessProxy_GetWebAuthnProcessConnection
    , WebProcessProxy_IsAXAuthenticated
    , WebProcessProxy_ShouldTerminate
    , WrappedAsyncMessageForTesting
    , Last = WrappedAsyncMessageForTesting
};

ReceiverName receiverName(MessageName);
const char* description(MessageName);
bool isValidMessageName(MessageName);
constexpr bool messageIsSync(MessageName name)
{
    return name >= MessageName::GPUConnectionToWebProcess_EnsureAudioSession;
}

} // namespace IPC

namespace WTF {

template<>
struct EnumTraits<IPC::MessageName> {
    template<typename T>
    static std::enable_if_t<sizeof(T) == sizeof(IPC::MessageName) && std::is_unsigned_v<T>, bool> isValidEnum(T messageName)
    {
        if (messageName > WTF::enumToUnderlyingType(IPC::MessageName::Last))
            return false;
        return IPC::isValidMessageName(static_cast<IPC::MessageName>(messageName));
    }
};

} // namespace WTF
